import { ComponentInternalInstance, VNodeProps, AllowedComponentProps, ComponentCustomProps, Slot, ComponentPublicInstance, ComponentOptionsBase, Ref, ComponentOptionsMixin, ReactiveEffect, nextTick, WatchOptions, WatchStopHandle, ShallowUnwrapRef, ComponentCustomProperties, App, DefineComponent, PropType, EmitsOptions } from 'vue';
import { init } from 'echarts/core';
import { EChartsOption, TitleOption, LegendComponentOption, GridOption, XAXisOption, YAXisOption, PolarOption, RadiusAxisOption, AngleAxisOption, RadarOption, DataZoomComponentOption, VisualMapComponentOption, ToolboxComponentOption, AxisPointerOption, BrushOption, GeoOption, ParallelCoordinateSystemOption, SingleAxisOption, TimelineOption, GraphicComponentLooseOption, CalendarOption, DatasetOption, AriaOption, SeriesOption } from 'echarts/types/dist/shared';

declare type InitParameters = Parameters<typeof init>;
declare type Theme = NonNullable<InitParameters[1]>;
interface SetOptionOpts {
    notMerge?: boolean;
    lazyUpdate?: boolean;
    silent?: boolean;
    replaceMerge?: any;
    transition?: any;
}

declare const VeChart: {
    new (...args: any[]): {
        $: ComponentInternalInstance;
        $data: {};
        $props: Partial<{
            option: EChartsOption;
            initOptions: {
                renderer?: ("canvas" | "svg") | undefined;
                devicePixelRatio?: number | undefined;
                width?: number | undefined;
                height?: number | undefined;
                locale?: string | {
                    time: {
                        month: string[];
                        monthAbbr: string[];
                        dayOfWeek: string[];
                        dayOfWeekAbbr: string[];
                    };
                    legend: {
                        selector: {
                            all: string;
                            inverse: string;
                        };
                    };
                    toolbox: {
                        brush: {
                            title: {
                                rect: string;
                                polygon: string;
                                lineX: string;
                                lineY: string;
                                keep: string;
                                clear: string;
                            };
                        };
                        dataView: {
                            title: string;
                            lang: string[];
                        };
                        dataZoom: {
                            title: {
                                zoom: string;
                                back: string;
                            };
                        };
                        magicType: {
                            title: {
                                line: string;
                                bar: string;
                                stack: string;
                                tiled: string;
                            };
                        };
                        restore: {
                            title: string;
                        };
                        saveAsImage: {
                            title: string;
                            lang: string[];
                        };
                    };
                    series: {
                        typeNames: {
                            pie: string;
                            bar: string;
                            line: string;
                            scatter: string;
                            effectScatter: string;
                            radar: string;
                            tree: string;
                            treemap: string;
                            boxplot: string;
                            candlestick: string;
                            k: string;
                            heatmap: string;
                            map: string;
                            parallel: string;
                            lines: string;
                            graph: string;
                            sankey: string;
                            funnel: string;
                            gauge: string;
                            pictorialBar: string;
                            themeRiver: string;
                            sunburst: string;
                        };
                    };
                    aria: {
                        general: {
                            withTitle: string;
                            withoutTitle: string;
                        };
                        series: {
                            single: {
                                prefix: string;
                                withName: string;
                                withoutName: string;
                            };
                            multiple: {
                                prefix: string;
                                withName: string;
                                withoutName: string;
                                separator: {
                                    middle: string;
                                    end: string;
                                };
                            };
                        };
                        data: {
                            allData: string;
                            partialData: string;
                            withName: string;
                            withoutName: string;
                            separator: {
                                middle: string;
                                end: string;
                            };
                        };
                    };
                } | undefined;
            };
            theme: Theme;
            setOptionOpts: SetOptionOpts;
            height: number;
            needUpdate: boolean;
        }> & Omit<Readonly<{
            option: EChartsOption;
            initOptions: {
                renderer?: ("canvas" | "svg") | undefined;
                devicePixelRatio?: number | undefined;
                width?: number | undefined;
                height?: number | undefined;
                locale?: string | {
                    time: {
                        month: string[];
                        monthAbbr: string[];
                        dayOfWeek: string[];
                        dayOfWeekAbbr: string[];
                    };
                    legend: {
                        selector: {
                            all: string;
                            inverse: string;
                        };
                    };
                    toolbox: {
                        brush: {
                            title: {
                                rect: string;
                                polygon: string;
                                lineX: string;
                                lineY: string;
                                keep: string;
                                clear: string;
                            };
                        };
                        dataView: {
                            title: string;
                            lang: string[];
                        };
                        dataZoom: {
                            title: {
                                zoom: string;
                                back: string;
                            };
                        };
                        magicType: {
                            title: {
                                line: string;
                                bar: string;
                                stack: string;
                                tiled: string;
                            };
                        };
                        restore: {
                            title: string;
                        };
                        saveAsImage: {
                            title: string;
                            lang: string[];
                        };
                    };
                    series: {
                        typeNames: {
                            pie: string;
                            bar: string;
                            line: string;
                            scatter: string;
                            effectScatter: string;
                            radar: string;
                            tree: string;
                            treemap: string;
                            boxplot: string;
                            candlestick: string;
                            k: string;
                            heatmap: string;
                            map: string;
                            parallel: string;
                            lines: string;
                            graph: string;
                            sankey: string;
                            funnel: string;
                            gauge: string;
                            pictorialBar: string;
                            themeRiver: string;
                            sunburst: string;
                        };
                    };
                    aria: {
                        general: {
                            withTitle: string;
                            withoutTitle: string;
                        };
                        series: {
                            single: {
                                prefix: string;
                                withName: string;
                                withoutName: string;
                            };
                            multiple: {
                                prefix: string;
                                withName: string;
                                withoutName: string;
                                separator: {
                                    middle: string;
                                    end: string;
                                };
                            };
                        };
                        data: {
                            allData: string;
                            partialData: string;
                            withName: string;
                            withoutName: string;
                            separator: {
                                middle: string;
                                end: string;
                            };
                        };
                    };
                } | undefined;
            };
            theme: Theme;
            setOptionOpts: SetOptionOpts;
            height: number;
            needUpdate: boolean;
        } & {}> & VNodeProps & AllowedComponentProps & ComponentCustomProps, "option" | "initOptions" | "theme" | "setOptionOpts" | "height" | "needUpdate">;
        $attrs: {
            [x: string]: unknown;
        };
        $refs: {
            [x: string]: unknown;
        };
        $slots: Readonly<{
            [name: string]: Slot | undefined;
        }>;
        $root: ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}>> | null;
        $parent: ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}>> | null;
        $emit: (event: string, ...args: any[]) => void;
        $el: any;
        $options: ComponentOptionsBase<Readonly<{
            option: EChartsOption;
            initOptions: {
                renderer?: ("canvas" | "svg") | undefined;
                devicePixelRatio?: number | undefined;
                width?: number | undefined;
                height?: number | undefined;
                locale?: string | {
                    time: {
                        month: string[];
                        monthAbbr: string[];
                        dayOfWeek: string[];
                        dayOfWeekAbbr: string[];
                    };
                    legend: {
                        selector: {
                            all: string;
                            inverse: string;
                        };
                    };
                    toolbox: {
                        brush: {
                            title: {
                                rect: string;
                                polygon: string;
                                lineX: string;
                                lineY: string;
                                keep: string;
                                clear: string;
                            };
                        };
                        dataView: {
                            title: string;
                            lang: string[];
                        };
                        dataZoom: {
                            title: {
                                zoom: string;
                                back: string;
                            };
                        };
                        magicType: {
                            title: {
                                line: string;
                                bar: string;
                                stack: string;
                                tiled: string;
                            };
                        };
                        restore: {
                            title: string;
                        };
                        saveAsImage: {
                            title: string;
                            lang: string[];
                        };
                    };
                    series: {
                        typeNames: {
                            pie: string;
                            bar: string;
                            line: string;
                            scatter: string;
                            effectScatter: string;
                            radar: string;
                            tree: string;
                            treemap: string;
                            boxplot: string;
                            candlestick: string;
                            k: string;
                            heatmap: string;
                            map: string;
                            parallel: string;
                            lines: string;
                            graph: string;
                            sankey: string;
                            funnel: string;
                            gauge: string;
                            pictorialBar: string;
                            themeRiver: string;
                            sunburst: string;
                        };
                    };
                    aria: {
                        general: {
                            withTitle: string;
                            withoutTitle: string;
                        };
                        series: {
                            single: {
                                prefix: string;
                                withName: string;
                                withoutName: string;
                            };
                            multiple: {
                                prefix: string;
                                withName: string;
                                withoutName: string;
                                separator: {
                                    middle: string;
                                    end: string;
                                };
                            };
                        };
                        data: {
                            allData: string;
                            partialData: string;
                            withName: string;
                            withoutName: string;
                            separator: {
                                middle: string;
                                end: string;
                            };
                        };
                    };
                } | undefined;
            };
            theme: Theme;
            setOptionOpts: SetOptionOpts;
            height: number;
            needUpdate: boolean;
        } & {}>, {
            echartsRef: Ref<HTMLElement | undefined>;
            echartsStyle: {
                display: string;
                width: string;
                height: string;
            };
        }, unknown, {}, {}, ComponentOptionsMixin, ComponentOptionsMixin, Record<string, any>, string, {
            option: EChartsOption;
            initOptions: {
                renderer?: ("canvas" | "svg") | undefined;
                devicePixelRatio?: number | undefined;
                width?: number | undefined;
                height?: number | undefined;
                locale?: string | {
                    time: {
                        month: string[];
                        monthAbbr: string[];
                        dayOfWeek: string[];
                        dayOfWeekAbbr: string[];
                    };
                    legend: {
                        selector: {
                            all: string;
                            inverse: string;
                        };
                    };
                    toolbox: {
                        brush: {
                            title: {
                                rect: string;
                                polygon: string;
                                lineX: string;
                                lineY: string;
                                keep: string;
                                clear: string;
                            };
                        };
                        dataView: {
                            title: string;
                            lang: string[];
                        };
                        dataZoom: {
                            title: {
                                zoom: string;
                                back: string;
                            };
                        };
                        magicType: {
                            title: {
                                line: string;
                                bar: string;
                                stack: string;
                                tiled: string;
                            };
                        };
                        restore: {
                            title: string;
                        };
                        saveAsImage: {
                            title: string;
                            lang: string[];
                        };
                    };
                    series: {
                        typeNames: {
                            pie: string;
                            bar: string;
                            line: string;
                            scatter: string;
                            effectScatter: string;
                            radar: string;
                            tree: string;
                            treemap: string;
                            boxplot: string;
                            candlestick: string;
                            k: string;
                            heatmap: string;
                            map: string;
                            parallel: string;
                            lines: string;
                            graph: string;
                            sankey: string;
                            funnel: string;
                            gauge: string;
                            pictorialBar: string;
                            themeRiver: string;
                            sunburst: string;
                        };
                    };
                    aria: {
                        general: {
                            withTitle: string;
                            withoutTitle: string;
                        };
                        series: {
                            single: {
                                prefix: string;
                                withName: string;
                                withoutName: string;
                            };
                            multiple: {
                                prefix: string;
                                withName: string;
                                withoutName: string;
                                separator: {
                                    middle: string;
                                    end: string;
                                };
                            };
                        };
                        data: {
                            allData: string;
                            partialData: string;
                            withName: string;
                            withoutName: string;
                            separator: {
                                middle: string;
                                end: string;
                            };
                        };
                    };
                } | undefined;
            };
            theme: Theme;
            setOptionOpts: SetOptionOpts;
            height: number;
            needUpdate: boolean;
        }>;
        $forceUpdate: ReactiveEffect<any>;
        $nextTick: typeof nextTick;
        $watch(source: string | Function, cb: Function, options?: WatchOptions<boolean> | undefined): WatchStopHandle;
    } & Readonly<{
        option: EChartsOption;
        initOptions: {
            renderer?: ("canvas" | "svg") | undefined;
            devicePixelRatio?: number | undefined;
            width?: number | undefined;
            height?: number | undefined;
            locale?: string | {
                time: {
                    month: string[];
                    monthAbbr: string[];
                    dayOfWeek: string[];
                    dayOfWeekAbbr: string[];
                };
                legend: {
                    selector: {
                        all: string;
                        inverse: string;
                    };
                };
                toolbox: {
                    brush: {
                        title: {
                            rect: string;
                            polygon: string;
                            lineX: string;
                            lineY: string;
                            keep: string;
                            clear: string;
                        };
                    };
                    dataView: {
                        title: string;
                        lang: string[];
                    };
                    dataZoom: {
                        title: {
                            zoom: string;
                            back: string;
                        };
                    };
                    magicType: {
                        title: {
                            line: string;
                            bar: string;
                            stack: string;
                            tiled: string;
                        };
                    };
                    restore: {
                        title: string;
                    };
                    saveAsImage: {
                        title: string;
                        lang: string[];
                    };
                };
                series: {
                    typeNames: {
                        pie: string;
                        bar: string;
                        line: string;
                        scatter: string;
                        effectScatter: string;
                        radar: string;
                        tree: string;
                        treemap: string;
                        boxplot: string;
                        candlestick: string;
                        k: string;
                        heatmap: string;
                        map: string;
                        parallel: string;
                        lines: string;
                        graph: string;
                        sankey: string;
                        funnel: string;
                        gauge: string;
                        pictorialBar: string;
                        themeRiver: string;
                        sunburst: string;
                    };
                };
                aria: {
                    general: {
                        withTitle: string;
                        withoutTitle: string;
                    };
                    series: {
                        single: {
                            prefix: string;
                            withName: string;
                            withoutName: string;
                        };
                        multiple: {
                            prefix: string;
                            withName: string;
                            withoutName: string;
                            separator: {
                                middle: string;
                                end: string;
                            };
                        };
                    };
                    data: {
                        allData: string;
                        partialData: string;
                        withName: string;
                        withoutName: string;
                        separator: {
                            middle: string;
                            end: string;
                        };
                    };
                };
            } | undefined;
        };
        theme: Theme;
        setOptionOpts: SetOptionOpts;
        height: number;
        needUpdate: boolean;
    } & {}> & ShallowUnwrapRef<{
        echartsRef: Ref<HTMLElement | undefined>;
        echartsStyle: {
            display: string;
            width: string;
            height: string;
        };
    }> & {} & {} & ComponentCustomProperties;
    __isFragment?: undefined;
    __isTeleport?: undefined;
    __isSuspense?: undefined;
} & ComponentOptionsBase<Readonly<{
    option: EChartsOption;
    initOptions: {
        renderer?: ("canvas" | "svg") | undefined;
        devicePixelRatio?: number | undefined;
        width?: number | undefined;
        height?: number | undefined;
        locale?: string | {
            time: {
                month: string[];
                monthAbbr: string[];
                dayOfWeek: string[];
                dayOfWeekAbbr: string[];
            };
            legend: {
                selector: {
                    all: string;
                    inverse: string;
                };
            };
            toolbox: {
                brush: {
                    title: {
                        rect: string;
                        polygon: string;
                        lineX: string;
                        lineY: string;
                        keep: string;
                        clear: string;
                    };
                };
                dataView: {
                    title: string;
                    lang: string[];
                };
                dataZoom: {
                    title: {
                        zoom: string;
                        back: string;
                    };
                };
                magicType: {
                    title: {
                        line: string;
                        bar: string;
                        stack: string;
                        tiled: string;
                    };
                };
                restore: {
                    title: string;
                };
                saveAsImage: {
                    title: string;
                    lang: string[];
                };
            };
            series: {
                typeNames: {
                    pie: string;
                    bar: string;
                    line: string;
                    scatter: string;
                    effectScatter: string;
                    radar: string;
                    tree: string;
                    treemap: string;
                    boxplot: string;
                    candlestick: string;
                    k: string;
                    heatmap: string;
                    map: string;
                    parallel: string;
                    lines: string;
                    graph: string;
                    sankey: string;
                    funnel: string;
                    gauge: string;
                    pictorialBar: string;
                    themeRiver: string;
                    sunburst: string;
                };
            };
            aria: {
                general: {
                    withTitle: string;
                    withoutTitle: string;
                };
                series: {
                    single: {
                        prefix: string;
                        withName: string;
                        withoutName: string;
                    };
                    multiple: {
                        prefix: string;
                        withName: string;
                        withoutName: string;
                        separator: {
                            middle: string;
                            end: string;
                        };
                    };
                };
                data: {
                    allData: string;
                    partialData: string;
                    withName: string;
                    withoutName: string;
                    separator: {
                        middle: string;
                        end: string;
                    };
                };
            };
        } | undefined;
    };
    theme: Theme;
    setOptionOpts: SetOptionOpts;
    height: number;
    needUpdate: boolean;
} & {}>, {
    echartsRef: Ref<HTMLElement | undefined>;
    echartsStyle: {
        display: string;
        width: string;
        height: string;
    };
}, unknown, {}, {}, ComponentOptionsMixin, ComponentOptionsMixin, Record<string, any>, string, {
    option: EChartsOption;
    initOptions: {
        renderer?: ("canvas" | "svg") | undefined;
        devicePixelRatio?: number | undefined;
        width?: number | undefined;
        height?: number | undefined;
        locale?: string | {
            time: {
                month: string[];
                monthAbbr: string[];
                dayOfWeek: string[];
                dayOfWeekAbbr: string[];
            };
            legend: {
                selector: {
                    all: string;
                    inverse: string;
                };
            };
            toolbox: {
                brush: {
                    title: {
                        rect: string;
                        polygon: string;
                        lineX: string;
                        lineY: string;
                        keep: string;
                        clear: string;
                    };
                };
                dataView: {
                    title: string;
                    lang: string[];
                };
                dataZoom: {
                    title: {
                        zoom: string;
                        back: string;
                    };
                };
                magicType: {
                    title: {
                        line: string;
                        bar: string;
                        stack: string;
                        tiled: string;
                    };
                };
                restore: {
                    title: string;
                };
                saveAsImage: {
                    title: string;
                    lang: string[];
                };
            };
            series: {
                typeNames: {
                    pie: string;
                    bar: string;
                    line: string;
                    scatter: string;
                    effectScatter: string;
                    radar: string;
                    tree: string;
                    treemap: string;
                    boxplot: string;
                    candlestick: string;
                    k: string;
                    heatmap: string;
                    map: string;
                    parallel: string;
                    lines: string;
                    graph: string;
                    sankey: string;
                    funnel: string;
                    gauge: string;
                    pictorialBar: string;
                    themeRiver: string;
                    sunburst: string;
                };
            };
            aria: {
                general: {
                    withTitle: string;
                    withoutTitle: string;
                };
                series: {
                    single: {
                        prefix: string;
                        withName: string;
                        withoutName: string;
                    };
                    multiple: {
                        prefix: string;
                        withName: string;
                        withoutName: string;
                        separator: {
                            middle: string;
                            end: string;
                        };
                    };
                };
                data: {
                    allData: string;
                    partialData: string;
                    withName: string;
                    withoutName: string;
                    separator: {
                        middle: string;
                        end: string;
                    };
                };
            };
        } | undefined;
    };
    theme: Theme;
    setOptionOpts: SetOptionOpts;
    height: number;
    needUpdate: boolean;
}> & VNodeProps & AllowedComponentProps & ComponentCustomProps & {
    install(app: App<any>): void;
} & Plugin;

declare const BarChart: {
    new (...args: any[]): {
        $: ComponentInternalInstance;
        $data: {
            initOptions: {
                renderer: string;
            };
            needUpdate: boolean;
            setOptionOpts: {};
            mergedOption: {};
        };
        $props: Partial<{
            option: EChartsOption;
            animation: boolean;
            darkMode: string | boolean;
            useUTC: boolean;
            variant: string;
            loading: boolean;
            emptyText: string;
        } & {}> & Omit<Readonly<{
            option: EChartsOption;
            animation: boolean;
            darkMode: string | boolean;
            useUTC: boolean;
            variant: string;
            loading: boolean;
            emptyText: string;
        } & {
            title?: TitleOption | undefined;
            legend?: LegendComponentOption | undefined;
            grid?: GridOption | undefined;
            xAxis?: XAXisOption | undefined;
            yAxis?: YAXisOption | undefined;
            polar?: PolarOption | undefined;
            radiusAxis?: RadiusAxisOption | undefined;
            angleAxis?: AngleAxisOption | undefined;
            radar?: RadarOption | undefined;
            dataZoom?: DataZoomComponentOption | undefined;
            visualMap?: VisualMapComponentOption | undefined;
            color?: unknown[] | undefined;
            toolbox?: ToolboxComponentOption | undefined;
            axisPointer?: AxisPointerOption | undefined;
            animationDurationUpdate?: number | Function | undefined;
            animationEasingUpdate?: string | Function | undefined;
            brush?: BrushOption | undefined;
            geo?: GeoOption | undefined;
            parallel?: ParallelCoordinateSystemOption | undefined;
            parallelAxis?: ParallelCoordinateSystemOption | undefined;
            singleAxis?: SingleAxisOption | undefined;
            timeline?: TimelineOption | undefined;
            graphic?: GraphicComponentLooseOption | undefined;
            tooltip?: ToolboxComponentOption | undefined;
            calendar?: CalendarOption | undefined;
            dataset?: DatasetOption | undefined;
            aria?: AriaOption | undefined;
            series?: SeriesOption | undefined;
            blendMode?: string | undefined;
            data?: unknown;
            hoverLayerThreshold?: number | undefined;
            stateAnimation?: Record<string, any> | undefined;
            animationThreshold?: number | undefined;
            animationDuration?: number | Function | undefined;
            animationEasing?: string | Function | undefined;
            animationDelay?: number | Function | undefined;
            animationDelayUpdate?: string | Function | undefined;
            backgroundColor?: unknown;
            textStyle?: Record<string, any> | undefined;
            options?: Record<string, any> | undefined;
            media?: unknown[] | undefined;
            settings?: unknown;
        }> & Readonly<{} & {}> & VNodeProps & AllowedComponentProps & ComponentCustomProps, "option" | "animation" | "darkMode" | "useUTC" | "variant" | "loading" | "emptyText">;
        $attrs: {
            [x: string]: unknown;
        };
        $refs: {
            [x: string]: unknown;
        };
        $slots: Readonly<{
            [name: string]: Slot | undefined;
        }>;
        $root: ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}>> | null;
        $parent: ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}>> | null;
        $emit: ((event: string, ...args: any[]) => void) | ((event: string, ...args: any[]) => void);
        $el: any;
        $options: ComponentOptionsBase<Readonly<{} & {}>, void, {}, {}, {}, ComponentOptionsMixin, DefineComponent<{
            title: PropType<TitleOption>;
            legend: PropType<LegendComponentOption>;
            grid: PropType<GridOption>;
            xAxis: PropType<XAXisOption>;
            yAxis: PropType<YAXisOption>;
            polar: PropType<PolarOption>;
            radiusAxis: PropType<RadiusAxisOption>;
            angleAxis: PropType<AngleAxisOption>;
            radar: PropType<RadarOption>;
            dataZoom: PropType<DataZoomComponentOption>;
            visualMap: PropType<VisualMapComponentOption>;
            tooltip: PropType<ToolboxComponentOption>;
            axisPointer: PropType<AxisPointerOption>;
            toolbox: PropType<ToolboxComponentOption>;
            brush: PropType<BrushOption>;
            geo: PropType<GeoOption>;
            parallel: PropType<ParallelCoordinateSystemOption>;
            parallelAxis: PropType<ParallelCoordinateSystemOption>;
            singleAxis: PropType<SingleAxisOption>;
            timeline: PropType<TimelineOption>;
            graphic: PropType<GraphicComponentLooseOption>;
            calendar: PropType<CalendarOption>;
            dataset: PropType<DatasetOption>;
            aria: PropType<AriaOption>;
            series: PropType<SeriesOption>;
            darkMode: {
                type: (StringConstructor | BooleanConstructor)[];
                default: string;
            };
            color: ArrayConstructor;
            backgroundColor: (ObjectConstructor | StringConstructor)[];
            textStyle: ObjectConstructor;
            animation: {
                type: BooleanConstructor;
                default: boolean;
            };
            animationThreshold: NumberConstructor;
            animationDuration: (NumberConstructor | FunctionConstructor)[];
            animationEasing: (StringConstructor | FunctionConstructor)[];
            animationDelay: (NumberConstructor | FunctionConstructor)[];
            animationDurationUpdate: (NumberConstructor | FunctionConstructor)[];
            animationEasingUpdate: (StringConstructor | FunctionConstructor)[];
            animationDelayUpdate: (StringConstructor | FunctionConstructor)[];
            stateAnimation: ObjectConstructor;
            blendMode: StringConstructor;
            hoverLayerThreshold: NumberConstructor;
            useUTC: {
                type: BooleanConstructor;
                default: boolean;
            };
            options: ObjectConstructor;
            media: ArrayConstructor;
            data: (ObjectConstructor | ArrayConstructor)[];
            settings: (ObjectConstructor | ArrayConstructor)[];
            variant: {
                type: StringConstructor;
                default: string;
            };
            loading: {
                type: BooleanConstructor;
                default: boolean;
            };
            emptyText: {
                type: StringConstructor;
                default: string;
            };
            option: {
                type: PropType<EChartsOption>;
                default: () => {};
            };
        }, unknown, {
            initOptions: {
                renderer: string;
            };
            needUpdate: boolean;
            setOptionOpts: {};
            mergedOption: {};
        }, {
            chartOpts(): Record<string, any>;
            isEmptyData(): boolean;
        }, {
            mergePropsToOption(props: any): void;
            forcedUpdate(): void;
        }, ComponentOptionsMixin, ComponentOptionsMixin, Record<string, any>, string, VNodeProps & AllowedComponentProps & ComponentCustomProps, Readonly<{
            option: EChartsOption;
            animation: boolean;
            darkMode: string | boolean;
            useUTC: boolean;
            variant: string;
            loading: boolean;
            emptyText: string;
        } & {
            title?: TitleOption | undefined;
            legend?: LegendComponentOption | undefined;
            grid?: GridOption | undefined;
            xAxis?: XAXisOption | undefined;
            yAxis?: YAXisOption | undefined;
            polar?: PolarOption | undefined;
            radiusAxis?: RadiusAxisOption | undefined;
            angleAxis?: AngleAxisOption | undefined;
            radar?: RadarOption | undefined;
            dataZoom?: DataZoomComponentOption | undefined;
            visualMap?: VisualMapComponentOption | undefined;
            color?: unknown[] | undefined;
            toolbox?: ToolboxComponentOption | undefined;
            axisPointer?: AxisPointerOption | undefined;
            animationDurationUpdate?: number | Function | undefined;
            animationEasingUpdate?: string | Function | undefined;
            brush?: BrushOption | undefined;
            geo?: GeoOption | undefined;
            parallel?: ParallelCoordinateSystemOption | undefined;
            parallelAxis?: ParallelCoordinateSystemOption | undefined;
            singleAxis?: SingleAxisOption | undefined;
            timeline?: TimelineOption | undefined;
            graphic?: GraphicComponentLooseOption | undefined;
            tooltip?: ToolboxComponentOption | undefined;
            calendar?: CalendarOption | undefined;
            dataset?: DatasetOption | undefined;
            aria?: AriaOption | undefined;
            series?: SeriesOption | undefined;
            blendMode?: string | undefined;
            data?: unknown;
            hoverLayerThreshold?: number | undefined;
            stateAnimation?: Record<string, any> | undefined;
            animationThreshold?: number | undefined;
            animationDuration?: number | Function | undefined;
            animationEasing?: string | Function | undefined;
            animationDelay?: number | Function | undefined;
            animationDelayUpdate?: string | Function | undefined;
            backgroundColor?: unknown;
            textStyle?: Record<string, any> | undefined;
            options?: Record<string, any> | undefined;
            media?: unknown[] | undefined;
            settings?: unknown;
        }>, {
            option: EChartsOption;
            animation: boolean;
            darkMode: string | boolean;
            useUTC: boolean;
            variant: string;
            loading: boolean;
            emptyText: string;
        }>, EmitsOptions, string, {}>;
        $forceUpdate: ReactiveEffect<any>;
        $nextTick: typeof nextTick;
        $watch(source: string | Function, cb: Function, options?: WatchOptions<boolean> | undefined): WatchStopHandle;
    } & Readonly<{
        option: EChartsOption;
        animation: boolean;
        darkMode: string | boolean;
        useUTC: boolean;
        variant: string;
        loading: boolean;
        emptyText: string;
    } & {
        title?: TitleOption | undefined;
        legend?: LegendComponentOption | undefined;
        grid?: GridOption | undefined;
        xAxis?: XAXisOption | undefined;
        yAxis?: YAXisOption | undefined;
        polar?: PolarOption | undefined;
        radiusAxis?: RadiusAxisOption | undefined;
        angleAxis?: AngleAxisOption | undefined;
        radar?: RadarOption | undefined;
        dataZoom?: DataZoomComponentOption | undefined;
        visualMap?: VisualMapComponentOption | undefined;
        color?: unknown[] | undefined;
        toolbox?: ToolboxComponentOption | undefined;
        axisPointer?: AxisPointerOption | undefined;
        animationDurationUpdate?: number | Function | undefined;
        animationEasingUpdate?: string | Function | undefined;
        brush?: BrushOption | undefined;
        geo?: GeoOption | undefined;
        parallel?: ParallelCoordinateSystemOption | undefined;
        parallelAxis?: ParallelCoordinateSystemOption | undefined;
        singleAxis?: SingleAxisOption | undefined;
        timeline?: TimelineOption | undefined;
        graphic?: GraphicComponentLooseOption | undefined;
        tooltip?: ToolboxComponentOption | undefined;
        calendar?: CalendarOption | undefined;
        dataset?: DatasetOption | undefined;
        aria?: AriaOption | undefined;
        series?: SeriesOption | undefined;
        blendMode?: string | undefined;
        data?: unknown;
        hoverLayerThreshold?: number | undefined;
        stateAnimation?: Record<string, any> | undefined;
        animationThreshold?: number | undefined;
        animationDuration?: number | Function | undefined;
        animationEasing?: string | Function | undefined;
        animationDelay?: number | Function | undefined;
        animationDelayUpdate?: string | Function | undefined;
        backgroundColor?: unknown;
        textStyle?: Record<string, any> | undefined;
        options?: Record<string, any> | undefined;
        media?: unknown[] | undefined;
        settings?: unknown;
    }> & Readonly<{} & {}> & ShallowUnwrapRef<{}> & {
        initOptions: {
            renderer: string;
        };
        needUpdate: boolean;
        setOptionOpts: {};
        mergedOption: {};
    } & {
        chartOpts: Record<string, any>;
        isEmptyData: boolean;
    } & {
        mergePropsToOption(props: any): void;
        forcedUpdate(): void;
    } & ComponentCustomProperties;
    __isFragment?: undefined;
    __isTeleport?: undefined;
    __isSuspense?: undefined;
} & ComponentOptionsBase<Readonly<{} & {}>, void, {}, {}, {}, ComponentOptionsMixin, DefineComponent<{
    title: PropType<TitleOption>;
    legend: PropType<LegendComponentOption>;
    grid: PropType<GridOption>;
    xAxis: PropType<XAXisOption>;
    yAxis: PropType<YAXisOption>;
    polar: PropType<PolarOption>;
    radiusAxis: PropType<RadiusAxisOption>;
    angleAxis: PropType<AngleAxisOption>;
    radar: PropType<RadarOption>;
    dataZoom: PropType<DataZoomComponentOption>;
    visualMap: PropType<VisualMapComponentOption>;
    tooltip: PropType<ToolboxComponentOption>;
    axisPointer: PropType<AxisPointerOption>;
    toolbox: PropType<ToolboxComponentOption>;
    brush: PropType<BrushOption>;
    geo: PropType<GeoOption>;
    parallel: PropType<ParallelCoordinateSystemOption>;
    parallelAxis: PropType<ParallelCoordinateSystemOption>;
    singleAxis: PropType<SingleAxisOption>;
    timeline: PropType<TimelineOption>;
    graphic: PropType<GraphicComponentLooseOption>;
    calendar: PropType<CalendarOption>;
    dataset: PropType<DatasetOption>;
    aria: PropType<AriaOption>;
    series: PropType<SeriesOption>;
    darkMode: {
        type: (StringConstructor | BooleanConstructor)[];
        default: string;
    };
    color: ArrayConstructor;
    backgroundColor: (ObjectConstructor | StringConstructor)[];
    textStyle: ObjectConstructor;
    animation: {
        type: BooleanConstructor;
        default: boolean;
    };
    animationThreshold: NumberConstructor;
    animationDuration: (NumberConstructor | FunctionConstructor)[];
    animationEasing: (StringConstructor | FunctionConstructor)[];
    animationDelay: (NumberConstructor | FunctionConstructor)[];
    animationDurationUpdate: (NumberConstructor | FunctionConstructor)[];
    animationEasingUpdate: (StringConstructor | FunctionConstructor)[];
    animationDelayUpdate: (StringConstructor | FunctionConstructor)[];
    stateAnimation: ObjectConstructor;
    blendMode: StringConstructor;
    hoverLayerThreshold: NumberConstructor;
    useUTC: {
        type: BooleanConstructor;
        default: boolean;
    };
    options: ObjectConstructor;
    media: ArrayConstructor;
    data: (ObjectConstructor | ArrayConstructor)[];
    settings: (ObjectConstructor | ArrayConstructor)[];
    variant: {
        type: StringConstructor;
        default: string;
    };
    loading: {
        type: BooleanConstructor;
        default: boolean;
    };
    emptyText: {
        type: StringConstructor;
        default: string;
    };
    option: {
        type: PropType<EChartsOption>;
        default: () => {};
    };
}, unknown, {
    initOptions: {
        renderer: string;
    };
    needUpdate: boolean;
    setOptionOpts: {};
    mergedOption: {};
}, {
    chartOpts(): Record<string, any>;
    isEmptyData(): boolean;
}, {
    mergePropsToOption(props: any): void;
    forcedUpdate(): void;
}, ComponentOptionsMixin, ComponentOptionsMixin, Record<string, any>, string, VNodeProps & AllowedComponentProps & ComponentCustomProps, Readonly<{
    option: EChartsOption;
    animation: boolean;
    darkMode: string | boolean;
    useUTC: boolean;
    variant: string;
    loading: boolean;
    emptyText: string;
} & {
    title?: TitleOption | undefined;
    legend?: LegendComponentOption | undefined;
    grid?: GridOption | undefined;
    xAxis?: XAXisOption | undefined;
    yAxis?: YAXisOption | undefined;
    polar?: PolarOption | undefined;
    radiusAxis?: RadiusAxisOption | undefined;
    angleAxis?: AngleAxisOption | undefined;
    radar?: RadarOption | undefined;
    dataZoom?: DataZoomComponentOption | undefined;
    visualMap?: VisualMapComponentOption | undefined;
    color?: unknown[] | undefined;
    toolbox?: ToolboxComponentOption | undefined;
    axisPointer?: AxisPointerOption | undefined;
    animationDurationUpdate?: number | Function | undefined;
    animationEasingUpdate?: string | Function | undefined;
    brush?: BrushOption | undefined;
    geo?: GeoOption | undefined;
    parallel?: ParallelCoordinateSystemOption | undefined;
    parallelAxis?: ParallelCoordinateSystemOption | undefined;
    singleAxis?: SingleAxisOption | undefined;
    timeline?: TimelineOption | undefined;
    graphic?: GraphicComponentLooseOption | undefined;
    tooltip?: ToolboxComponentOption | undefined;
    calendar?: CalendarOption | undefined;
    dataset?: DatasetOption | undefined;
    aria?: AriaOption | undefined;
    series?: SeriesOption | undefined;
    blendMode?: string | undefined;
    data?: unknown;
    hoverLayerThreshold?: number | undefined;
    stateAnimation?: Record<string, any> | undefined;
    animationThreshold?: number | undefined;
    animationDuration?: number | Function | undefined;
    animationEasing?: string | Function | undefined;
    animationDelay?: number | Function | undefined;
    animationDelayUpdate?: string | Function | undefined;
    backgroundColor?: unknown;
    textStyle?: Record<string, any> | undefined;
    options?: Record<string, any> | undefined;
    media?: unknown[] | undefined;
    settings?: unknown;
}>, {
    option: EChartsOption;
    animation: boolean;
    darkMode: string | boolean;
    useUTC: boolean;
    variant: string;
    loading: boolean;
    emptyText: string;
}>, EmitsOptions, string, {}> & VNodeProps & AllowedComponentProps & ComponentCustomProps & {
    install(app: App<any>): void;
} & Plugin;
declare const VeBarChart: {
    new (...args: any[]): {
        $: ComponentInternalInstance;
        $data: {
            initOptions: {
                renderer: string;
            };
            needUpdate: boolean;
            setOptionOpts: {};
            mergedOption: {};
        };
        $props: Partial<{
            option: EChartsOption;
            animation: boolean;
            darkMode: string | boolean;
            useUTC: boolean;
            variant: string;
            loading: boolean;
            emptyText: string;
        } & {}> & Omit<Readonly<{
            option: EChartsOption;
            animation: boolean;
            darkMode: string | boolean;
            useUTC: boolean;
            variant: string;
            loading: boolean;
            emptyText: string;
        } & {
            title?: TitleOption | undefined;
            legend?: LegendComponentOption | undefined;
            grid?: GridOption | undefined;
            xAxis?: XAXisOption | undefined;
            yAxis?: YAXisOption | undefined;
            polar?: PolarOption | undefined;
            radiusAxis?: RadiusAxisOption | undefined;
            angleAxis?: AngleAxisOption | undefined;
            radar?: RadarOption | undefined;
            dataZoom?: DataZoomComponentOption | undefined;
            visualMap?: VisualMapComponentOption | undefined;
            color?: unknown[] | undefined;
            toolbox?: ToolboxComponentOption | undefined;
            axisPointer?: AxisPointerOption | undefined;
            animationDurationUpdate?: number | Function | undefined;
            animationEasingUpdate?: string | Function | undefined;
            brush?: BrushOption | undefined;
            geo?: GeoOption | undefined;
            parallel?: ParallelCoordinateSystemOption | undefined;
            parallelAxis?: ParallelCoordinateSystemOption | undefined;
            singleAxis?: SingleAxisOption | undefined;
            timeline?: TimelineOption | undefined;
            graphic?: GraphicComponentLooseOption | undefined;
            tooltip?: ToolboxComponentOption | undefined;
            calendar?: CalendarOption | undefined;
            dataset?: DatasetOption | undefined;
            aria?: AriaOption | undefined;
            series?: SeriesOption | undefined;
            blendMode?: string | undefined;
            data?: unknown;
            hoverLayerThreshold?: number | undefined;
            stateAnimation?: Record<string, any> | undefined;
            animationThreshold?: number | undefined;
            animationDuration?: number | Function | undefined;
            animationEasing?: string | Function | undefined;
            animationDelay?: number | Function | undefined;
            animationDelayUpdate?: string | Function | undefined;
            backgroundColor?: unknown;
            textStyle?: Record<string, any> | undefined;
            options?: Record<string, any> | undefined;
            media?: unknown[] | undefined;
            settings?: unknown;
        }> & Readonly<{} & {}> & VNodeProps & AllowedComponentProps & ComponentCustomProps, "option" | "animation" | "darkMode" | "useUTC" | "variant" | "loading" | "emptyText">;
        $attrs: {
            [x: string]: unknown;
        };
        $refs: {
            [x: string]: unknown;
        };
        $slots: Readonly<{
            [name: string]: Slot | undefined;
        }>;
        $root: ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}>> | null;
        $parent: ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}>> | null;
        $emit: ((event: string, ...args: any[]) => void) | ((event: string, ...args: any[]) => void);
        $el: any;
        $options: ComponentOptionsBase<Readonly<{} & {}>, {}, {}, {}, {}, ComponentOptionsMixin, DefineComponent<{
            title: PropType<TitleOption>;
            legend: PropType<LegendComponentOption>;
            grid: PropType<GridOption>;
            xAxis: PropType<XAXisOption>;
            yAxis: PropType<YAXisOption>;
            polar: PropType<PolarOption>;
            radiusAxis: PropType<RadiusAxisOption>;
            angleAxis: PropType<AngleAxisOption>;
            radar: PropType<RadarOption>;
            dataZoom: PropType<DataZoomComponentOption>;
            visualMap: PropType<VisualMapComponentOption>;
            tooltip: PropType<ToolboxComponentOption>;
            axisPointer: PropType<AxisPointerOption>;
            toolbox: PropType<ToolboxComponentOption>;
            brush: PropType<BrushOption>;
            geo: PropType<GeoOption>;
            parallel: PropType<ParallelCoordinateSystemOption>;
            parallelAxis: PropType<ParallelCoordinateSystemOption>;
            singleAxis: PropType<SingleAxisOption>;
            timeline: PropType<TimelineOption>;
            graphic: PropType<GraphicComponentLooseOption>;
            calendar: PropType<CalendarOption>;
            dataset: PropType<DatasetOption>;
            aria: PropType<AriaOption>;
            series: PropType<SeriesOption>;
            darkMode: {
                type: (StringConstructor | BooleanConstructor)[];
                default: string;
            };
            color: ArrayConstructor;
            backgroundColor: (ObjectConstructor | StringConstructor)[];
            textStyle: ObjectConstructor;
            animation: {
                type: BooleanConstructor;
                default: boolean;
            };
            animationThreshold: NumberConstructor;
            animationDuration: (NumberConstructor | FunctionConstructor)[];
            animationEasing: (StringConstructor | FunctionConstructor)[];
            animationDelay: (NumberConstructor | FunctionConstructor)[];
            animationDurationUpdate: (NumberConstructor | FunctionConstructor)[];
            animationEasingUpdate: (StringConstructor | FunctionConstructor)[];
            animationDelayUpdate: (StringConstructor | FunctionConstructor)[];
            stateAnimation: ObjectConstructor;
            blendMode: StringConstructor;
            hoverLayerThreshold: NumberConstructor;
            useUTC: {
                type: BooleanConstructor;
                default: boolean;
            };
            options: ObjectConstructor;
            media: ArrayConstructor;
            data: (ObjectConstructor | ArrayConstructor)[];
            settings: (ObjectConstructor | ArrayConstructor)[];
            variant: {
                type: StringConstructor;
                default: string;
            };
            loading: {
                type: BooleanConstructor;
                default: boolean;
            };
            emptyText: {
                type: StringConstructor;
                default: string;
            };
            option: {
                type: PropType<EChartsOption>;
                default: () => {};
            };
        }, unknown, {
            initOptions: {
                renderer: string;
            };
            needUpdate: boolean;
            setOptionOpts: {};
            mergedOption: {};
        }, {
            chartOpts(): Record<string, any>;
            isEmptyData(): boolean;
        }, {
            mergePropsToOption(props: any): void;
            forcedUpdate(): void;
        }, ComponentOptionsMixin, ComponentOptionsMixin, Record<string, any>, string, VNodeProps & AllowedComponentProps & ComponentCustomProps, Readonly<{
            option: EChartsOption;
            animation: boolean;
            darkMode: string | boolean;
            useUTC: boolean;
            variant: string;
            loading: boolean;
            emptyText: string;
        } & {
            title?: TitleOption | undefined;
            legend?: LegendComponentOption | undefined;
            grid?: GridOption | undefined;
            xAxis?: XAXisOption | undefined;
            yAxis?: YAXisOption | undefined;
            polar?: PolarOption | undefined;
            radiusAxis?: RadiusAxisOption | undefined;
            angleAxis?: AngleAxisOption | undefined;
            radar?: RadarOption | undefined;
            dataZoom?: DataZoomComponentOption | undefined;
            visualMap?: VisualMapComponentOption | undefined;
            color?: unknown[] | undefined;
            toolbox?: ToolboxComponentOption | undefined;
            axisPointer?: AxisPointerOption | undefined;
            animationDurationUpdate?: number | Function | undefined;
            animationEasingUpdate?: string | Function | undefined;
            brush?: BrushOption | undefined;
            geo?: GeoOption | undefined;
            parallel?: ParallelCoordinateSystemOption | undefined;
            parallelAxis?: ParallelCoordinateSystemOption | undefined;
            singleAxis?: SingleAxisOption | undefined;
            timeline?: TimelineOption | undefined;
            graphic?: GraphicComponentLooseOption | undefined;
            tooltip?: ToolboxComponentOption | undefined;
            calendar?: CalendarOption | undefined;
            dataset?: DatasetOption | undefined;
            aria?: AriaOption | undefined;
            series?: SeriesOption | undefined;
            blendMode?: string | undefined;
            data?: unknown;
            hoverLayerThreshold?: number | undefined;
            stateAnimation?: Record<string, any> | undefined;
            animationThreshold?: number | undefined;
            animationDuration?: number | Function | undefined;
            animationEasing?: string | Function | undefined;
            animationDelay?: number | Function | undefined;
            animationDelayUpdate?: string | Function | undefined;
            backgroundColor?: unknown;
            textStyle?: Record<string, any> | undefined;
            options?: Record<string, any> | undefined;
            media?: unknown[] | undefined;
            settings?: unknown;
        }>, {
            option: EChartsOption;
            animation: boolean;
            darkMode: string | boolean;
            useUTC: boolean;
            variant: string;
            loading: boolean;
            emptyText: string;
        }>, EmitsOptions, string, {}>;
        $forceUpdate: ReactiveEffect<any>;
        $nextTick: typeof nextTick;
        $watch(source: string | Function, cb: Function, options?: WatchOptions<boolean> | undefined): WatchStopHandle;
    } & Readonly<{
        option: EChartsOption;
        animation: boolean;
        darkMode: string | boolean;
        useUTC: boolean;
        variant: string;
        loading: boolean;
        emptyText: string;
    } & {
        title?: TitleOption | undefined;
        legend?: LegendComponentOption | undefined;
        grid?: GridOption | undefined;
        xAxis?: XAXisOption | undefined;
        yAxis?: YAXisOption | undefined;
        polar?: PolarOption | undefined;
        radiusAxis?: RadiusAxisOption | undefined;
        angleAxis?: AngleAxisOption | undefined;
        radar?: RadarOption | undefined;
        dataZoom?: DataZoomComponentOption | undefined;
        visualMap?: VisualMapComponentOption | undefined;
        color?: unknown[] | undefined;
        toolbox?: ToolboxComponentOption | undefined;
        axisPointer?: AxisPointerOption | undefined;
        animationDurationUpdate?: number | Function | undefined;
        animationEasingUpdate?: string | Function | undefined;
        brush?: BrushOption | undefined;
        geo?: GeoOption | undefined;
        parallel?: ParallelCoordinateSystemOption | undefined;
        parallelAxis?: ParallelCoordinateSystemOption | undefined;
        singleAxis?: SingleAxisOption | undefined;
        timeline?: TimelineOption | undefined;
        graphic?: GraphicComponentLooseOption | undefined;
        tooltip?: ToolboxComponentOption | undefined;
        calendar?: CalendarOption | undefined;
        dataset?: DatasetOption | undefined;
        aria?: AriaOption | undefined;
        series?: SeriesOption | undefined;
        blendMode?: string | undefined;
        data?: unknown;
        hoverLayerThreshold?: number | undefined;
        stateAnimation?: Record<string, any> | undefined;
        animationThreshold?: number | undefined;
        animationDuration?: number | Function | undefined;
        animationEasing?: string | Function | undefined;
        animationDelay?: number | Function | undefined;
        animationDelayUpdate?: string | Function | undefined;
        backgroundColor?: unknown;
        textStyle?: Record<string, any> | undefined;
        options?: Record<string, any> | undefined;
        media?: unknown[] | undefined;
        settings?: unknown;
    }> & Readonly<{} & {}> & ShallowUnwrapRef<{}> & {
        initOptions: {
            renderer: string;
        };
        needUpdate: boolean;
        setOptionOpts: {};
        mergedOption: {};
    } & {
        chartOpts: Record<string, any>;
        isEmptyData: boolean;
    } & {
        mergePropsToOption(props: any): void;
        forcedUpdate(): void;
    } & ComponentCustomProperties;
    __isFragment?: undefined;
    __isTeleport?: undefined;
    __isSuspense?: undefined;
} & ComponentOptionsBase<Readonly<{} & {}>, {}, {}, {}, {}, ComponentOptionsMixin, DefineComponent<{
    title: PropType<TitleOption>;
    legend: PropType<LegendComponentOption>;
    grid: PropType<GridOption>;
    xAxis: PropType<XAXisOption>;
    yAxis: PropType<YAXisOption>;
    polar: PropType<PolarOption>;
    radiusAxis: PropType<RadiusAxisOption>;
    angleAxis: PropType<AngleAxisOption>;
    radar: PropType<RadarOption>;
    dataZoom: PropType<DataZoomComponentOption>;
    visualMap: PropType<VisualMapComponentOption>;
    tooltip: PropType<ToolboxComponentOption>;
    axisPointer: PropType<AxisPointerOption>;
    toolbox: PropType<ToolboxComponentOption>;
    brush: PropType<BrushOption>;
    geo: PropType<GeoOption>;
    parallel: PropType<ParallelCoordinateSystemOption>;
    parallelAxis: PropType<ParallelCoordinateSystemOption>;
    singleAxis: PropType<SingleAxisOption>;
    timeline: PropType<TimelineOption>;
    graphic: PropType<GraphicComponentLooseOption>;
    calendar: PropType<CalendarOption>;
    dataset: PropType<DatasetOption>;
    aria: PropType<AriaOption>;
    series: PropType<SeriesOption>;
    darkMode: {
        type: (StringConstructor | BooleanConstructor)[];
        default: string;
    };
    color: ArrayConstructor;
    backgroundColor: (ObjectConstructor | StringConstructor)[];
    textStyle: ObjectConstructor;
    animation: {
        type: BooleanConstructor;
        default: boolean;
    };
    animationThreshold: NumberConstructor;
    animationDuration: (NumberConstructor | FunctionConstructor)[];
    animationEasing: (StringConstructor | FunctionConstructor)[];
    animationDelay: (NumberConstructor | FunctionConstructor)[];
    animationDurationUpdate: (NumberConstructor | FunctionConstructor)[];
    animationEasingUpdate: (StringConstructor | FunctionConstructor)[];
    animationDelayUpdate: (StringConstructor | FunctionConstructor)[];
    stateAnimation: ObjectConstructor;
    blendMode: StringConstructor;
    hoverLayerThreshold: NumberConstructor;
    useUTC: {
        type: BooleanConstructor;
        default: boolean;
    };
    options: ObjectConstructor;
    media: ArrayConstructor;
    data: (ObjectConstructor | ArrayConstructor)[];
    settings: (ObjectConstructor | ArrayConstructor)[];
    variant: {
        type: StringConstructor;
        default: string;
    };
    loading: {
        type: BooleanConstructor;
        default: boolean;
    };
    emptyText: {
        type: StringConstructor;
        default: string;
    };
    option: {
        type: PropType<EChartsOption>;
        default: () => {};
    };
}, unknown, {
    initOptions: {
        renderer: string;
    };
    needUpdate: boolean;
    setOptionOpts: {};
    mergedOption: {};
}, {
    chartOpts(): Record<string, any>;
    isEmptyData(): boolean;
}, {
    mergePropsToOption(props: any): void;
    forcedUpdate(): void;
}, ComponentOptionsMixin, ComponentOptionsMixin, Record<string, any>, string, VNodeProps & AllowedComponentProps & ComponentCustomProps, Readonly<{
    option: EChartsOption;
    animation: boolean;
    darkMode: string | boolean;
    useUTC: boolean;
    variant: string;
    loading: boolean;
    emptyText: string;
} & {
    title?: TitleOption | undefined;
    legend?: LegendComponentOption | undefined;
    grid?: GridOption | undefined;
    xAxis?: XAXisOption | undefined;
    yAxis?: YAXisOption | undefined;
    polar?: PolarOption | undefined;
    radiusAxis?: RadiusAxisOption | undefined;
    angleAxis?: AngleAxisOption | undefined;
    radar?: RadarOption | undefined;
    dataZoom?: DataZoomComponentOption | undefined;
    visualMap?: VisualMapComponentOption | undefined;
    color?: unknown[] | undefined;
    toolbox?: ToolboxComponentOption | undefined;
    axisPointer?: AxisPointerOption | undefined;
    animationDurationUpdate?: number | Function | undefined;
    animationEasingUpdate?: string | Function | undefined;
    brush?: BrushOption | undefined;
    geo?: GeoOption | undefined;
    parallel?: ParallelCoordinateSystemOption | undefined;
    parallelAxis?: ParallelCoordinateSystemOption | undefined;
    singleAxis?: SingleAxisOption | undefined;
    timeline?: TimelineOption | undefined;
    graphic?: GraphicComponentLooseOption | undefined;
    tooltip?: ToolboxComponentOption | undefined;
    calendar?: CalendarOption | undefined;
    dataset?: DatasetOption | undefined;
    aria?: AriaOption | undefined;
    series?: SeriesOption | undefined;
    blendMode?: string | undefined;
    data?: unknown;
    hoverLayerThreshold?: number | undefined;
    stateAnimation?: Record<string, any> | undefined;
    animationThreshold?: number | undefined;
    animationDuration?: number | Function | undefined;
    animationEasing?: string | Function | undefined;
    animationDelay?: number | Function | undefined;
    animationDelayUpdate?: string | Function | undefined;
    backgroundColor?: unknown;
    textStyle?: Record<string, any> | undefined;
    options?: Record<string, any> | undefined;
    media?: unknown[] | undefined;
    settings?: unknown;
}>, {
    option: EChartsOption;
    animation: boolean;
    darkMode: string | boolean;
    useUTC: boolean;
    variant: string;
    loading: boolean;
    emptyText: string;
}>, EmitsOptions, string, {}> & VNodeProps & AllowedComponentProps & ComponentCustomProps & {
    install(app: App<any>): void;
} & Plugin;

declare const LineChart: {
    new (...args: any[]): {
        $: ComponentInternalInstance;
        $data: {
            initOptions: {
                renderer: string;
            };
            needUpdate: boolean;
            setOptionOpts: {};
            mergedOption: {};
        };
        $props: Partial<{
            option: EChartsOption;
            animation: boolean;
            darkMode: string | boolean;
            useUTC: boolean;
            variant: string;
            loading: boolean;
            emptyText: string;
        } & {}> & Omit<Readonly<{
            option: EChartsOption;
            animation: boolean;
            darkMode: string | boolean;
            useUTC: boolean;
            variant: string;
            loading: boolean;
            emptyText: string;
        } & {
            title?: TitleOption | undefined;
            legend?: LegendComponentOption | undefined;
            grid?: GridOption | undefined;
            xAxis?: XAXisOption | undefined;
            yAxis?: YAXisOption | undefined;
            polar?: PolarOption | undefined;
            radiusAxis?: RadiusAxisOption | undefined;
            angleAxis?: AngleAxisOption | undefined;
            radar?: RadarOption | undefined;
            dataZoom?: DataZoomComponentOption | undefined;
            visualMap?: VisualMapComponentOption | undefined;
            color?: unknown[] | undefined;
            toolbox?: ToolboxComponentOption | undefined;
            axisPointer?: AxisPointerOption | undefined;
            animationDurationUpdate?: number | Function | undefined;
            animationEasingUpdate?: string | Function | undefined;
            brush?: BrushOption | undefined;
            geo?: GeoOption | undefined;
            parallel?: ParallelCoordinateSystemOption | undefined;
            parallelAxis?: ParallelCoordinateSystemOption | undefined;
            singleAxis?: SingleAxisOption | undefined;
            timeline?: TimelineOption | undefined;
            graphic?: GraphicComponentLooseOption | undefined;
            tooltip?: ToolboxComponentOption | undefined;
            calendar?: CalendarOption | undefined;
            dataset?: DatasetOption | undefined;
            aria?: AriaOption | undefined;
            series?: SeriesOption | undefined;
            blendMode?: string | undefined;
            data?: unknown;
            hoverLayerThreshold?: number | undefined;
            stateAnimation?: Record<string, any> | undefined;
            animationThreshold?: number | undefined;
            animationDuration?: number | Function | undefined;
            animationEasing?: string | Function | undefined;
            animationDelay?: number | Function | undefined;
            animationDelayUpdate?: string | Function | undefined;
            backgroundColor?: unknown;
            textStyle?: Record<string, any> | undefined;
            options?: Record<string, any> | undefined;
            media?: unknown[] | undefined;
            settings?: unknown;
        }> & Readonly<{} & {}> & VNodeProps & AllowedComponentProps & ComponentCustomProps, "option" | "animation" | "darkMode" | "useUTC" | "variant" | "loading" | "emptyText">;
        $attrs: {
            [x: string]: unknown;
        };
        $refs: {
            [x: string]: unknown;
        };
        $slots: Readonly<{
            [name: string]: Slot | undefined;
        }>;
        $root: ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}>> | null;
        $parent: ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}>> | null;
        $emit: ((event: string, ...args: any[]) => void) | ((event: string, ...args: any[]) => void);
        $el: any;
        $options: ComponentOptionsBase<Readonly<{} & {}>, void, {}, {}, {}, ComponentOptionsMixin, DefineComponent<{
            title: PropType<TitleOption>;
            legend: PropType<LegendComponentOption>;
            grid: PropType<GridOption>;
            xAxis: PropType<XAXisOption>;
            yAxis: PropType<YAXisOption>;
            polar: PropType<PolarOption>;
            radiusAxis: PropType<RadiusAxisOption>;
            angleAxis: PropType<AngleAxisOption>;
            radar: PropType<RadarOption>;
            dataZoom: PropType<DataZoomComponentOption>;
            visualMap: PropType<VisualMapComponentOption>;
            tooltip: PropType<ToolboxComponentOption>;
            axisPointer: PropType<AxisPointerOption>;
            toolbox: PropType<ToolboxComponentOption>;
            brush: PropType<BrushOption>;
            geo: PropType<GeoOption>;
            parallel: PropType<ParallelCoordinateSystemOption>;
            parallelAxis: PropType<ParallelCoordinateSystemOption>;
            singleAxis: PropType<SingleAxisOption>;
            timeline: PropType<TimelineOption>;
            graphic: PropType<GraphicComponentLooseOption>;
            calendar: PropType<CalendarOption>;
            dataset: PropType<DatasetOption>;
            aria: PropType<AriaOption>;
            series: PropType<SeriesOption>;
            darkMode: {
                type: (StringConstructor | BooleanConstructor)[];
                default: string;
            };
            color: ArrayConstructor;
            backgroundColor: (ObjectConstructor | StringConstructor)[];
            textStyle: ObjectConstructor;
            animation: {
                type: BooleanConstructor;
                default: boolean;
            };
            animationThreshold: NumberConstructor;
            animationDuration: (NumberConstructor | FunctionConstructor)[];
            animationEasing: (StringConstructor | FunctionConstructor)[];
            animationDelay: (NumberConstructor | FunctionConstructor)[];
            animationDurationUpdate: (NumberConstructor | FunctionConstructor)[];
            animationEasingUpdate: (StringConstructor | FunctionConstructor)[];
            animationDelayUpdate: (StringConstructor | FunctionConstructor)[];
            stateAnimation: ObjectConstructor;
            blendMode: StringConstructor;
            hoverLayerThreshold: NumberConstructor;
            useUTC: {
                type: BooleanConstructor;
                default: boolean;
            };
            options: ObjectConstructor;
            media: ArrayConstructor;
            data: (ObjectConstructor | ArrayConstructor)[];
            settings: (ObjectConstructor | ArrayConstructor)[];
            variant: {
                type: StringConstructor;
                default: string;
            };
            loading: {
                type: BooleanConstructor;
                default: boolean;
            };
            emptyText: {
                type: StringConstructor;
                default: string;
            };
            option: {
                type: PropType<EChartsOption>;
                default: () => {};
            };
        }, unknown, {
            initOptions: {
                renderer: string;
            };
            needUpdate: boolean;
            setOptionOpts: {};
            mergedOption: {};
        }, {
            chartOpts(): Record<string, any>;
            isEmptyData(): boolean;
        }, {
            mergePropsToOption(props: any): void;
            forcedUpdate(): void;
        }, ComponentOptionsMixin, ComponentOptionsMixin, Record<string, any>, string, VNodeProps & AllowedComponentProps & ComponentCustomProps, Readonly<{
            option: EChartsOption;
            animation: boolean;
            darkMode: string | boolean;
            useUTC: boolean;
            variant: string;
            loading: boolean;
            emptyText: string;
        } & {
            title?: TitleOption | undefined;
            legend?: LegendComponentOption | undefined;
            grid?: GridOption | undefined;
            xAxis?: XAXisOption | undefined;
            yAxis?: YAXisOption | undefined;
            polar?: PolarOption | undefined;
            radiusAxis?: RadiusAxisOption | undefined;
            angleAxis?: AngleAxisOption | undefined;
            radar?: RadarOption | undefined;
            dataZoom?: DataZoomComponentOption | undefined;
            visualMap?: VisualMapComponentOption | undefined;
            color?: unknown[] | undefined;
            toolbox?: ToolboxComponentOption | undefined;
            axisPointer?: AxisPointerOption | undefined;
            animationDurationUpdate?: number | Function | undefined;
            animationEasingUpdate?: string | Function | undefined;
            brush?: BrushOption | undefined;
            geo?: GeoOption | undefined;
            parallel?: ParallelCoordinateSystemOption | undefined;
            parallelAxis?: ParallelCoordinateSystemOption | undefined;
            singleAxis?: SingleAxisOption | undefined;
            timeline?: TimelineOption | undefined;
            graphic?: GraphicComponentLooseOption | undefined;
            tooltip?: ToolboxComponentOption | undefined;
            calendar?: CalendarOption | undefined;
            dataset?: DatasetOption | undefined;
            aria?: AriaOption | undefined;
            series?: SeriesOption | undefined;
            blendMode?: string | undefined;
            data?: unknown;
            hoverLayerThreshold?: number | undefined;
            stateAnimation?: Record<string, any> | undefined;
            animationThreshold?: number | undefined;
            animationDuration?: number | Function | undefined;
            animationEasing?: string | Function | undefined;
            animationDelay?: number | Function | undefined;
            animationDelayUpdate?: string | Function | undefined;
            backgroundColor?: unknown;
            textStyle?: Record<string, any> | undefined;
            options?: Record<string, any> | undefined;
            media?: unknown[] | undefined;
            settings?: unknown;
        }>, {
            option: EChartsOption;
            animation: boolean;
            darkMode: string | boolean;
            useUTC: boolean;
            variant: string;
            loading: boolean;
            emptyText: string;
        }>, EmitsOptions, string, {}>;
        $forceUpdate: ReactiveEffect<any>;
        $nextTick: typeof nextTick;
        $watch(source: string | Function, cb: Function, options?: WatchOptions<boolean> | undefined): WatchStopHandle;
    } & Readonly<{
        option: EChartsOption;
        animation: boolean;
        darkMode: string | boolean;
        useUTC: boolean;
        variant: string;
        loading: boolean;
        emptyText: string;
    } & {
        title?: TitleOption | undefined;
        legend?: LegendComponentOption | undefined;
        grid?: GridOption | undefined;
        xAxis?: XAXisOption | undefined;
        yAxis?: YAXisOption | undefined;
        polar?: PolarOption | undefined;
        radiusAxis?: RadiusAxisOption | undefined;
        angleAxis?: AngleAxisOption | undefined;
        radar?: RadarOption | undefined;
        dataZoom?: DataZoomComponentOption | undefined;
        visualMap?: VisualMapComponentOption | undefined;
        color?: unknown[] | undefined;
        toolbox?: ToolboxComponentOption | undefined;
        axisPointer?: AxisPointerOption | undefined;
        animationDurationUpdate?: number | Function | undefined;
        animationEasingUpdate?: string | Function | undefined;
        brush?: BrushOption | undefined;
        geo?: GeoOption | undefined;
        parallel?: ParallelCoordinateSystemOption | undefined;
        parallelAxis?: ParallelCoordinateSystemOption | undefined;
        singleAxis?: SingleAxisOption | undefined;
        timeline?: TimelineOption | undefined;
        graphic?: GraphicComponentLooseOption | undefined;
        tooltip?: ToolboxComponentOption | undefined;
        calendar?: CalendarOption | undefined;
        dataset?: DatasetOption | undefined;
        aria?: AriaOption | undefined;
        series?: SeriesOption | undefined;
        blendMode?: string | undefined;
        data?: unknown;
        hoverLayerThreshold?: number | undefined;
        stateAnimation?: Record<string, any> | undefined;
        animationThreshold?: number | undefined;
        animationDuration?: number | Function | undefined;
        animationEasing?: string | Function | undefined;
        animationDelay?: number | Function | undefined;
        animationDelayUpdate?: string | Function | undefined;
        backgroundColor?: unknown;
        textStyle?: Record<string, any> | undefined;
        options?: Record<string, any> | undefined;
        media?: unknown[] | undefined;
        settings?: unknown;
    }> & Readonly<{} & {}> & ShallowUnwrapRef<{}> & {
        initOptions: {
            renderer: string;
        };
        needUpdate: boolean;
        setOptionOpts: {};
        mergedOption: {};
    } & {
        chartOpts: Record<string, any>;
        isEmptyData: boolean;
    } & {
        mergePropsToOption(props: any): void;
        forcedUpdate(): void;
    } & ComponentCustomProperties;
    __isFragment?: undefined;
    __isTeleport?: undefined;
    __isSuspense?: undefined;
} & ComponentOptionsBase<Readonly<{} & {}>, void, {}, {}, {}, ComponentOptionsMixin, DefineComponent<{
    title: PropType<TitleOption>;
    legend: PropType<LegendComponentOption>;
    grid: PropType<GridOption>;
    xAxis: PropType<XAXisOption>;
    yAxis: PropType<YAXisOption>;
    polar: PropType<PolarOption>;
    radiusAxis: PropType<RadiusAxisOption>;
    angleAxis: PropType<AngleAxisOption>;
    radar: PropType<RadarOption>;
    dataZoom: PropType<DataZoomComponentOption>;
    visualMap: PropType<VisualMapComponentOption>;
    tooltip: PropType<ToolboxComponentOption>;
    axisPointer: PropType<AxisPointerOption>;
    toolbox: PropType<ToolboxComponentOption>;
    brush: PropType<BrushOption>;
    geo: PropType<GeoOption>;
    parallel: PropType<ParallelCoordinateSystemOption>;
    parallelAxis: PropType<ParallelCoordinateSystemOption>;
    singleAxis: PropType<SingleAxisOption>;
    timeline: PropType<TimelineOption>;
    graphic: PropType<GraphicComponentLooseOption>;
    calendar: PropType<CalendarOption>;
    dataset: PropType<DatasetOption>;
    aria: PropType<AriaOption>;
    series: PropType<SeriesOption>;
    darkMode: {
        type: (StringConstructor | BooleanConstructor)[];
        default: string;
    };
    color: ArrayConstructor;
    backgroundColor: (ObjectConstructor | StringConstructor)[];
    textStyle: ObjectConstructor;
    animation: {
        type: BooleanConstructor;
        default: boolean;
    };
    animationThreshold: NumberConstructor;
    animationDuration: (NumberConstructor | FunctionConstructor)[];
    animationEasing: (StringConstructor | FunctionConstructor)[];
    animationDelay: (NumberConstructor | FunctionConstructor)[];
    animationDurationUpdate: (NumberConstructor | FunctionConstructor)[];
    animationEasingUpdate: (StringConstructor | FunctionConstructor)[];
    animationDelayUpdate: (StringConstructor | FunctionConstructor)[];
    stateAnimation: ObjectConstructor;
    blendMode: StringConstructor;
    hoverLayerThreshold: NumberConstructor;
    useUTC: {
        type: BooleanConstructor;
        default: boolean;
    };
    options: ObjectConstructor;
    media: ArrayConstructor;
    data: (ObjectConstructor | ArrayConstructor)[];
    settings: (ObjectConstructor | ArrayConstructor)[];
    variant: {
        type: StringConstructor;
        default: string;
    };
    loading: {
        type: BooleanConstructor;
        default: boolean;
    };
    emptyText: {
        type: StringConstructor;
        default: string;
    };
    option: {
        type: PropType<EChartsOption>;
        default: () => {};
    };
}, unknown, {
    initOptions: {
        renderer: string;
    };
    needUpdate: boolean;
    setOptionOpts: {};
    mergedOption: {};
}, {
    chartOpts(): Record<string, any>;
    isEmptyData(): boolean;
}, {
    mergePropsToOption(props: any): void;
    forcedUpdate(): void;
}, ComponentOptionsMixin, ComponentOptionsMixin, Record<string, any>, string, VNodeProps & AllowedComponentProps & ComponentCustomProps, Readonly<{
    option: EChartsOption;
    animation: boolean;
    darkMode: string | boolean;
    useUTC: boolean;
    variant: string;
    loading: boolean;
    emptyText: string;
} & {
    title?: TitleOption | undefined;
    legend?: LegendComponentOption | undefined;
    grid?: GridOption | undefined;
    xAxis?: XAXisOption | undefined;
    yAxis?: YAXisOption | undefined;
    polar?: PolarOption | undefined;
    radiusAxis?: RadiusAxisOption | undefined;
    angleAxis?: AngleAxisOption | undefined;
    radar?: RadarOption | undefined;
    dataZoom?: DataZoomComponentOption | undefined;
    visualMap?: VisualMapComponentOption | undefined;
    color?: unknown[] | undefined;
    toolbox?: ToolboxComponentOption | undefined;
    axisPointer?: AxisPointerOption | undefined;
    animationDurationUpdate?: number | Function | undefined;
    animationEasingUpdate?: string | Function | undefined;
    brush?: BrushOption | undefined;
    geo?: GeoOption | undefined;
    parallel?: ParallelCoordinateSystemOption | undefined;
    parallelAxis?: ParallelCoordinateSystemOption | undefined;
    singleAxis?: SingleAxisOption | undefined;
    timeline?: TimelineOption | undefined;
    graphic?: GraphicComponentLooseOption | undefined;
    tooltip?: ToolboxComponentOption | undefined;
    calendar?: CalendarOption | undefined;
    dataset?: DatasetOption | undefined;
    aria?: AriaOption | undefined;
    series?: SeriesOption | undefined;
    blendMode?: string | undefined;
    data?: unknown;
    hoverLayerThreshold?: number | undefined;
    stateAnimation?: Record<string, any> | undefined;
    animationThreshold?: number | undefined;
    animationDuration?: number | Function | undefined;
    animationEasing?: string | Function | undefined;
    animationDelay?: number | Function | undefined;
    animationDelayUpdate?: string | Function | undefined;
    backgroundColor?: unknown;
    textStyle?: Record<string, any> | undefined;
    options?: Record<string, any> | undefined;
    media?: unknown[] | undefined;
    settings?: unknown;
}>, {
    option: EChartsOption;
    animation: boolean;
    darkMode: string | boolean;
    useUTC: boolean;
    variant: string;
    loading: boolean;
    emptyText: string;
}>, EmitsOptions, string, {}> & VNodeProps & AllowedComponentProps & ComponentCustomProps & {
    install(app: App<any>): void;
} & Plugin;

declare const PieChart: {
    new (...args: any[]): {
        $: ComponentInternalInstance;
        $data: {
            initOptions: {
                renderer: string;
            };
            needUpdate: boolean;
            setOptionOpts: {};
            mergedOption: {};
        };
        $props: Partial<{
            option: EChartsOption;
            animation: boolean;
            darkMode: string | boolean;
            useUTC: boolean;
            variant: string;
            loading: boolean;
            emptyText: string;
        } & {}> & Omit<Readonly<{
            option: EChartsOption;
            animation: boolean;
            darkMode: string | boolean;
            useUTC: boolean;
            variant: string;
            loading: boolean;
            emptyText: string;
        } & {
            title?: TitleOption | undefined;
            legend?: LegendComponentOption | undefined;
            grid?: GridOption | undefined;
            xAxis?: XAXisOption | undefined;
            yAxis?: YAXisOption | undefined;
            polar?: PolarOption | undefined;
            radiusAxis?: RadiusAxisOption | undefined;
            angleAxis?: AngleAxisOption | undefined;
            radar?: RadarOption | undefined;
            dataZoom?: DataZoomComponentOption | undefined;
            visualMap?: VisualMapComponentOption | undefined;
            color?: unknown[] | undefined;
            toolbox?: ToolboxComponentOption | undefined;
            axisPointer?: AxisPointerOption | undefined;
            animationDurationUpdate?: number | Function | undefined;
            animationEasingUpdate?: string | Function | undefined;
            brush?: BrushOption | undefined;
            geo?: GeoOption | undefined;
            parallel?: ParallelCoordinateSystemOption | undefined;
            parallelAxis?: ParallelCoordinateSystemOption | undefined;
            singleAxis?: SingleAxisOption | undefined;
            timeline?: TimelineOption | undefined;
            graphic?: GraphicComponentLooseOption | undefined;
            tooltip?: ToolboxComponentOption | undefined;
            calendar?: CalendarOption | undefined;
            dataset?: DatasetOption | undefined;
            aria?: AriaOption | undefined;
            series?: SeriesOption | undefined;
            blendMode?: string | undefined;
            data?: unknown;
            hoverLayerThreshold?: number | undefined;
            stateAnimation?: Record<string, any> | undefined;
            animationThreshold?: number | undefined;
            animationDuration?: number | Function | undefined;
            animationEasing?: string | Function | undefined;
            animationDelay?: number | Function | undefined;
            animationDelayUpdate?: string | Function | undefined;
            backgroundColor?: unknown;
            textStyle?: Record<string, any> | undefined;
            options?: Record<string, any> | undefined;
            media?: unknown[] | undefined;
            settings?: unknown;
        }> & Readonly<{} & {}> & VNodeProps & AllowedComponentProps & ComponentCustomProps, "option" | "animation" | "darkMode" | "useUTC" | "variant" | "loading" | "emptyText">;
        $attrs: {
            [x: string]: unknown;
        };
        $refs: {
            [x: string]: unknown;
        };
        $slots: Readonly<{
            [name: string]: Slot | undefined;
        }>;
        $root: ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}>> | null;
        $parent: ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}>> | null;
        $emit: ((event: string, ...args: any[]) => void) | ((event: string, ...args: any[]) => void);
        $el: any;
        $options: ComponentOptionsBase<Readonly<{} & {}>, void, {}, {}, {}, ComponentOptionsMixin, DefineComponent<{
            title: PropType<TitleOption>;
            legend: PropType<LegendComponentOption>;
            grid: PropType<GridOption>;
            xAxis: PropType<XAXisOption>;
            yAxis: PropType<YAXisOption>;
            polar: PropType<PolarOption>;
            radiusAxis: PropType<RadiusAxisOption>;
            angleAxis: PropType<AngleAxisOption>;
            radar: PropType<RadarOption>;
            dataZoom: PropType<DataZoomComponentOption>;
            visualMap: PropType<VisualMapComponentOption>;
            tooltip: PropType<ToolboxComponentOption>;
            axisPointer: PropType<AxisPointerOption>;
            toolbox: PropType<ToolboxComponentOption>;
            brush: PropType<BrushOption>;
            geo: PropType<GeoOption>;
            parallel: PropType<ParallelCoordinateSystemOption>;
            parallelAxis: PropType<ParallelCoordinateSystemOption>;
            singleAxis: PropType<SingleAxisOption>;
            timeline: PropType<TimelineOption>;
            graphic: PropType<GraphicComponentLooseOption>;
            calendar: PropType<CalendarOption>;
            dataset: PropType<DatasetOption>;
            aria: PropType<AriaOption>;
            series: PropType<SeriesOption>;
            darkMode: {
                type: (StringConstructor | BooleanConstructor)[];
                default: string;
            };
            color: ArrayConstructor;
            backgroundColor: (ObjectConstructor | StringConstructor)[];
            textStyle: ObjectConstructor;
            animation: {
                type: BooleanConstructor;
                default: boolean;
            };
            animationThreshold: NumberConstructor;
            animationDuration: (NumberConstructor | FunctionConstructor)[];
            animationEasing: (StringConstructor | FunctionConstructor)[];
            animationDelay: (NumberConstructor | FunctionConstructor)[];
            animationDurationUpdate: (NumberConstructor | FunctionConstructor)[];
            animationEasingUpdate: (StringConstructor | FunctionConstructor)[];
            animationDelayUpdate: (StringConstructor | FunctionConstructor)[];
            stateAnimation: ObjectConstructor;
            blendMode: StringConstructor;
            hoverLayerThreshold: NumberConstructor;
            useUTC: {
                type: BooleanConstructor;
                default: boolean;
            };
            options: ObjectConstructor;
            media: ArrayConstructor;
            data: (ObjectConstructor | ArrayConstructor)[];
            settings: (ObjectConstructor | ArrayConstructor)[];
            variant: {
                type: StringConstructor;
                default: string;
            };
            loading: {
                type: BooleanConstructor;
                default: boolean;
            };
            emptyText: {
                type: StringConstructor;
                default: string;
            };
            option: {
                type: PropType<EChartsOption>;
                default: () => {};
            };
        }, unknown, {
            initOptions: {
                renderer: string;
            };
            needUpdate: boolean;
            setOptionOpts: {};
            mergedOption: {};
        }, {
            chartOpts(): Record<string, any>;
            isEmptyData(): boolean;
        }, {
            mergePropsToOption(props: any): void;
            forcedUpdate(): void;
        }, ComponentOptionsMixin, ComponentOptionsMixin, Record<string, any>, string, VNodeProps & AllowedComponentProps & ComponentCustomProps, Readonly<{
            option: EChartsOption;
            animation: boolean;
            darkMode: string | boolean;
            useUTC: boolean;
            variant: string;
            loading: boolean;
            emptyText: string;
        } & {
            title?: TitleOption | undefined;
            legend?: LegendComponentOption | undefined;
            grid?: GridOption | undefined;
            xAxis?: XAXisOption | undefined;
            yAxis?: YAXisOption | undefined;
            polar?: PolarOption | undefined;
            radiusAxis?: RadiusAxisOption | undefined;
            angleAxis?: AngleAxisOption | undefined;
            radar?: RadarOption | undefined;
            dataZoom?: DataZoomComponentOption | undefined;
            visualMap?: VisualMapComponentOption | undefined;
            color?: unknown[] | undefined;
            toolbox?: ToolboxComponentOption | undefined;
            axisPointer?: AxisPointerOption | undefined;
            animationDurationUpdate?: number | Function | undefined;
            animationEasingUpdate?: string | Function | undefined;
            brush?: BrushOption | undefined;
            geo?: GeoOption | undefined;
            parallel?: ParallelCoordinateSystemOption | undefined;
            parallelAxis?: ParallelCoordinateSystemOption | undefined;
            singleAxis?: SingleAxisOption | undefined;
            timeline?: TimelineOption | undefined;
            graphic?: GraphicComponentLooseOption | undefined;
            tooltip?: ToolboxComponentOption | undefined;
            calendar?: CalendarOption | undefined;
            dataset?: DatasetOption | undefined;
            aria?: AriaOption | undefined;
            series?: SeriesOption | undefined;
            blendMode?: string | undefined;
            data?: unknown;
            hoverLayerThreshold?: number | undefined;
            stateAnimation?: Record<string, any> | undefined;
            animationThreshold?: number | undefined;
            animationDuration?: number | Function | undefined;
            animationEasing?: string | Function | undefined;
            animationDelay?: number | Function | undefined;
            animationDelayUpdate?: string | Function | undefined;
            backgroundColor?: unknown;
            textStyle?: Record<string, any> | undefined;
            options?: Record<string, any> | undefined;
            media?: unknown[] | undefined;
            settings?: unknown;
        }>, {
            option: EChartsOption;
            animation: boolean;
            darkMode: string | boolean;
            useUTC: boolean;
            variant: string;
            loading: boolean;
            emptyText: string;
        }>, EmitsOptions, string, {}>;
        $forceUpdate: ReactiveEffect<any>;
        $nextTick: typeof nextTick;
        $watch(source: string | Function, cb: Function, options?: WatchOptions<boolean> | undefined): WatchStopHandle;
    } & Readonly<{
        option: EChartsOption;
        animation: boolean;
        darkMode: string | boolean;
        useUTC: boolean;
        variant: string;
        loading: boolean;
        emptyText: string;
    } & {
        title?: TitleOption | undefined;
        legend?: LegendComponentOption | undefined;
        grid?: GridOption | undefined;
        xAxis?: XAXisOption | undefined;
        yAxis?: YAXisOption | undefined;
        polar?: PolarOption | undefined;
        radiusAxis?: RadiusAxisOption | undefined;
        angleAxis?: AngleAxisOption | undefined;
        radar?: RadarOption | undefined;
        dataZoom?: DataZoomComponentOption | undefined;
        visualMap?: VisualMapComponentOption | undefined;
        color?: unknown[] | undefined;
        toolbox?: ToolboxComponentOption | undefined;
        axisPointer?: AxisPointerOption | undefined;
        animationDurationUpdate?: number | Function | undefined;
        animationEasingUpdate?: string | Function | undefined;
        brush?: BrushOption | undefined;
        geo?: GeoOption | undefined;
        parallel?: ParallelCoordinateSystemOption | undefined;
        parallelAxis?: ParallelCoordinateSystemOption | undefined;
        singleAxis?: SingleAxisOption | undefined;
        timeline?: TimelineOption | undefined;
        graphic?: GraphicComponentLooseOption | undefined;
        tooltip?: ToolboxComponentOption | undefined;
        calendar?: CalendarOption | undefined;
        dataset?: DatasetOption | undefined;
        aria?: AriaOption | undefined;
        series?: SeriesOption | undefined;
        blendMode?: string | undefined;
        data?: unknown;
        hoverLayerThreshold?: number | undefined;
        stateAnimation?: Record<string, any> | undefined;
        animationThreshold?: number | undefined;
        animationDuration?: number | Function | undefined;
        animationEasing?: string | Function | undefined;
        animationDelay?: number | Function | undefined;
        animationDelayUpdate?: string | Function | undefined;
        backgroundColor?: unknown;
        textStyle?: Record<string, any> | undefined;
        options?: Record<string, any> | undefined;
        media?: unknown[] | undefined;
        settings?: unknown;
    }> & Readonly<{} & {}> & ShallowUnwrapRef<{}> & {
        initOptions: {
            renderer: string;
        };
        needUpdate: boolean;
        setOptionOpts: {};
        mergedOption: {};
    } & {
        chartOpts: Record<string, any>;
        isEmptyData: boolean;
    } & {
        mergePropsToOption(props: any): void;
        forcedUpdate(): void;
    } & ComponentCustomProperties;
    __isFragment?: undefined;
    __isTeleport?: undefined;
    __isSuspense?: undefined;
} & ComponentOptionsBase<Readonly<{} & {}>, void, {}, {}, {}, ComponentOptionsMixin, DefineComponent<{
    title: PropType<TitleOption>;
    legend: PropType<LegendComponentOption>;
    grid: PropType<GridOption>;
    xAxis: PropType<XAXisOption>;
    yAxis: PropType<YAXisOption>;
    polar: PropType<PolarOption>;
    radiusAxis: PropType<RadiusAxisOption>;
    angleAxis: PropType<AngleAxisOption>;
    radar: PropType<RadarOption>;
    dataZoom: PropType<DataZoomComponentOption>;
    visualMap: PropType<VisualMapComponentOption>;
    tooltip: PropType<ToolboxComponentOption>;
    axisPointer: PropType<AxisPointerOption>;
    toolbox: PropType<ToolboxComponentOption>;
    brush: PropType<BrushOption>;
    geo: PropType<GeoOption>;
    parallel: PropType<ParallelCoordinateSystemOption>;
    parallelAxis: PropType<ParallelCoordinateSystemOption>;
    singleAxis: PropType<SingleAxisOption>;
    timeline: PropType<TimelineOption>;
    graphic: PropType<GraphicComponentLooseOption>;
    calendar: PropType<CalendarOption>;
    dataset: PropType<DatasetOption>;
    aria: PropType<AriaOption>;
    series: PropType<SeriesOption>;
    darkMode: {
        type: (StringConstructor | BooleanConstructor)[];
        default: string;
    };
    color: ArrayConstructor;
    backgroundColor: (ObjectConstructor | StringConstructor)[];
    textStyle: ObjectConstructor;
    animation: {
        type: BooleanConstructor;
        default: boolean;
    };
    animationThreshold: NumberConstructor;
    animationDuration: (NumberConstructor | FunctionConstructor)[];
    animationEasing: (StringConstructor | FunctionConstructor)[];
    animationDelay: (NumberConstructor | FunctionConstructor)[];
    animationDurationUpdate: (NumberConstructor | FunctionConstructor)[];
    animationEasingUpdate: (StringConstructor | FunctionConstructor)[];
    animationDelayUpdate: (StringConstructor | FunctionConstructor)[];
    stateAnimation: ObjectConstructor;
    blendMode: StringConstructor;
    hoverLayerThreshold: NumberConstructor;
    useUTC: {
        type: BooleanConstructor;
        default: boolean;
    };
    options: ObjectConstructor;
    media: ArrayConstructor;
    data: (ObjectConstructor | ArrayConstructor)[];
    settings: (ObjectConstructor | ArrayConstructor)[];
    variant: {
        type: StringConstructor;
        default: string;
    };
    loading: {
        type: BooleanConstructor;
        default: boolean;
    };
    emptyText: {
        type: StringConstructor;
        default: string;
    };
    option: {
        type: PropType<EChartsOption>;
        default: () => {};
    };
}, unknown, {
    initOptions: {
        renderer: string;
    };
    needUpdate: boolean;
    setOptionOpts: {};
    mergedOption: {};
}, {
    chartOpts(): Record<string, any>;
    isEmptyData(): boolean;
}, {
    mergePropsToOption(props: any): void;
    forcedUpdate(): void;
}, ComponentOptionsMixin, ComponentOptionsMixin, Record<string, any>, string, VNodeProps & AllowedComponentProps & ComponentCustomProps, Readonly<{
    option: EChartsOption;
    animation: boolean;
    darkMode: string | boolean;
    useUTC: boolean;
    variant: string;
    loading: boolean;
    emptyText: string;
} & {
    title?: TitleOption | undefined;
    legend?: LegendComponentOption | undefined;
    grid?: GridOption | undefined;
    xAxis?: XAXisOption | undefined;
    yAxis?: YAXisOption | undefined;
    polar?: PolarOption | undefined;
    radiusAxis?: RadiusAxisOption | undefined;
    angleAxis?: AngleAxisOption | undefined;
    radar?: RadarOption | undefined;
    dataZoom?: DataZoomComponentOption | undefined;
    visualMap?: VisualMapComponentOption | undefined;
    color?: unknown[] | undefined;
    toolbox?: ToolboxComponentOption | undefined;
    axisPointer?: AxisPointerOption | undefined;
    animationDurationUpdate?: number | Function | undefined;
    animationEasingUpdate?: string | Function | undefined;
    brush?: BrushOption | undefined;
    geo?: GeoOption | undefined;
    parallel?: ParallelCoordinateSystemOption | undefined;
    parallelAxis?: ParallelCoordinateSystemOption | undefined;
    singleAxis?: SingleAxisOption | undefined;
    timeline?: TimelineOption | undefined;
    graphic?: GraphicComponentLooseOption | undefined;
    tooltip?: ToolboxComponentOption | undefined;
    calendar?: CalendarOption | undefined;
    dataset?: DatasetOption | undefined;
    aria?: AriaOption | undefined;
    series?: SeriesOption | undefined;
    blendMode?: string | undefined;
    data?: unknown;
    hoverLayerThreshold?: number | undefined;
    stateAnimation?: Record<string, any> | undefined;
    animationThreshold?: number | undefined;
    animationDuration?: number | Function | undefined;
    animationEasing?: string | Function | undefined;
    animationDelay?: number | Function | undefined;
    animationDelayUpdate?: string | Function | undefined;
    backgroundColor?: unknown;
    textStyle?: Record<string, any> | undefined;
    options?: Record<string, any> | undefined;
    media?: unknown[] | undefined;
    settings?: unknown;
}>, {
    option: EChartsOption;
    animation: boolean;
    darkMode: string | boolean;
    useUTC: boolean;
    variant: string;
    loading: boolean;
    emptyText: string;
}>, EmitsOptions, string, {}> & VNodeProps & AllowedComponentProps & ComponentCustomProps & {
    install(app: App<any>): void;
} & Plugin;

declare const FunnelChart: {
    new (...args: any[]): {
        $: ComponentInternalInstance;
        $data: {
            initOptions: {
                renderer: string;
            };
            needUpdate: boolean;
            setOptionOpts: {};
            mergedOption: {};
        };
        $props: Partial<{
            option: EChartsOption;
            animation: boolean;
            darkMode: string | boolean;
            useUTC: boolean;
            variant: string;
            loading: boolean;
            emptyText: string;
        } & {}> & Omit<Readonly<{
            option: EChartsOption;
            animation: boolean;
            darkMode: string | boolean;
            useUTC: boolean;
            variant: string;
            loading: boolean;
            emptyText: string;
        } & {
            title?: TitleOption | undefined;
            legend?: LegendComponentOption | undefined;
            grid?: GridOption | undefined;
            xAxis?: XAXisOption | undefined;
            yAxis?: YAXisOption | undefined;
            polar?: PolarOption | undefined;
            radiusAxis?: RadiusAxisOption | undefined;
            angleAxis?: AngleAxisOption | undefined;
            radar?: RadarOption | undefined;
            dataZoom?: DataZoomComponentOption | undefined;
            visualMap?: VisualMapComponentOption | undefined;
            color?: unknown[] | undefined;
            toolbox?: ToolboxComponentOption | undefined;
            axisPointer?: AxisPointerOption | undefined;
            animationDurationUpdate?: number | Function | undefined;
            animationEasingUpdate?: string | Function | undefined;
            brush?: BrushOption | undefined;
            geo?: GeoOption | undefined;
            parallel?: ParallelCoordinateSystemOption | undefined;
            parallelAxis?: ParallelCoordinateSystemOption | undefined;
            singleAxis?: SingleAxisOption | undefined;
            timeline?: TimelineOption | undefined;
            graphic?: GraphicComponentLooseOption | undefined;
            tooltip?: ToolboxComponentOption | undefined;
            calendar?: CalendarOption | undefined;
            dataset?: DatasetOption | undefined;
            aria?: AriaOption | undefined;
            series?: SeriesOption | undefined;
            blendMode?: string | undefined;
            data?: unknown;
            hoverLayerThreshold?: number | undefined;
            stateAnimation?: Record<string, any> | undefined;
            animationThreshold?: number | undefined;
            animationDuration?: number | Function | undefined;
            animationEasing?: string | Function | undefined;
            animationDelay?: number | Function | undefined;
            animationDelayUpdate?: string | Function | undefined;
            backgroundColor?: unknown;
            textStyle?: Record<string, any> | undefined;
            options?: Record<string, any> | undefined;
            media?: unknown[] | undefined;
            settings?: unknown;
        }> & Readonly<{} & {}> & VNodeProps & AllowedComponentProps & ComponentCustomProps, "option" | "animation" | "darkMode" | "useUTC" | "variant" | "loading" | "emptyText">;
        $attrs: {
            [x: string]: unknown;
        };
        $refs: {
            [x: string]: unknown;
        };
        $slots: Readonly<{
            [name: string]: Slot | undefined;
        }>;
        $root: ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}>> | null;
        $parent: ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}>> | null;
        $emit: ((event: string, ...args: any[]) => void) | ((event: string, ...args: any[]) => void);
        $el: any;
        $options: ComponentOptionsBase<Readonly<{} & {}>, void, {}, {}, {}, ComponentOptionsMixin, DefineComponent<{
            title: PropType<TitleOption>;
            legend: PropType<LegendComponentOption>;
            grid: PropType<GridOption>;
            xAxis: PropType<XAXisOption>;
            yAxis: PropType<YAXisOption>;
            polar: PropType<PolarOption>;
            radiusAxis: PropType<RadiusAxisOption>;
            angleAxis: PropType<AngleAxisOption>;
            radar: PropType<RadarOption>;
            dataZoom: PropType<DataZoomComponentOption>;
            visualMap: PropType<VisualMapComponentOption>;
            tooltip: PropType<ToolboxComponentOption>;
            axisPointer: PropType<AxisPointerOption>;
            toolbox: PropType<ToolboxComponentOption>;
            brush: PropType<BrushOption>;
            geo: PropType<GeoOption>;
            parallel: PropType<ParallelCoordinateSystemOption>;
            parallelAxis: PropType<ParallelCoordinateSystemOption>;
            singleAxis: PropType<SingleAxisOption>;
            timeline: PropType<TimelineOption>;
            graphic: PropType<GraphicComponentLooseOption>;
            calendar: PropType<CalendarOption>;
            dataset: PropType<DatasetOption>;
            aria: PropType<AriaOption>;
            series: PropType<SeriesOption>;
            darkMode: {
                type: (StringConstructor | BooleanConstructor)[];
                default: string;
            };
            color: ArrayConstructor;
            backgroundColor: (ObjectConstructor | StringConstructor)[];
            textStyle: ObjectConstructor;
            animation: {
                type: BooleanConstructor;
                default: boolean;
            };
            animationThreshold: NumberConstructor;
            animationDuration: (NumberConstructor | FunctionConstructor)[];
            animationEasing: (StringConstructor | FunctionConstructor)[];
            animationDelay: (NumberConstructor | FunctionConstructor)[];
            animationDurationUpdate: (NumberConstructor | FunctionConstructor)[];
            animationEasingUpdate: (StringConstructor | FunctionConstructor)[];
            animationDelayUpdate: (StringConstructor | FunctionConstructor)[];
            stateAnimation: ObjectConstructor;
            blendMode: StringConstructor;
            hoverLayerThreshold: NumberConstructor;
            useUTC: {
                type: BooleanConstructor;
                default: boolean;
            };
            options: ObjectConstructor;
            media: ArrayConstructor;
            data: (ObjectConstructor | ArrayConstructor)[];
            settings: (ObjectConstructor | ArrayConstructor)[];
            variant: {
                type: StringConstructor;
                default: string;
            };
            loading: {
                type: BooleanConstructor;
                default: boolean;
            };
            emptyText: {
                type: StringConstructor;
                default: string;
            };
            option: {
                type: PropType<EChartsOption>;
                default: () => {};
            };
        }, unknown, {
            initOptions: {
                renderer: string;
            };
            needUpdate: boolean;
            setOptionOpts: {};
            mergedOption: {};
        }, {
            chartOpts(): Record<string, any>;
            isEmptyData(): boolean;
        }, {
            mergePropsToOption(props: any): void;
            forcedUpdate(): void;
        }, ComponentOptionsMixin, ComponentOptionsMixin, Record<string, any>, string, VNodeProps & AllowedComponentProps & ComponentCustomProps, Readonly<{
            option: EChartsOption;
            animation: boolean;
            darkMode: string | boolean;
            useUTC: boolean;
            variant: string;
            loading: boolean;
            emptyText: string;
        } & {
            title?: TitleOption | undefined;
            legend?: LegendComponentOption | undefined;
            grid?: GridOption | undefined;
            xAxis?: XAXisOption | undefined;
            yAxis?: YAXisOption | undefined;
            polar?: PolarOption | undefined;
            radiusAxis?: RadiusAxisOption | undefined;
            angleAxis?: AngleAxisOption | undefined;
            radar?: RadarOption | undefined;
            dataZoom?: DataZoomComponentOption | undefined;
            visualMap?: VisualMapComponentOption | undefined;
            color?: unknown[] | undefined;
            toolbox?: ToolboxComponentOption | undefined;
            axisPointer?: AxisPointerOption | undefined;
            animationDurationUpdate?: number | Function | undefined;
            animationEasingUpdate?: string | Function | undefined;
            brush?: BrushOption | undefined;
            geo?: GeoOption | undefined;
            parallel?: ParallelCoordinateSystemOption | undefined;
            parallelAxis?: ParallelCoordinateSystemOption | undefined;
            singleAxis?: SingleAxisOption | undefined;
            timeline?: TimelineOption | undefined;
            graphic?: GraphicComponentLooseOption | undefined;
            tooltip?: ToolboxComponentOption | undefined;
            calendar?: CalendarOption | undefined;
            dataset?: DatasetOption | undefined;
            aria?: AriaOption | undefined;
            series?: SeriesOption | undefined;
            blendMode?: string | undefined;
            data?: unknown;
            hoverLayerThreshold?: number | undefined;
            stateAnimation?: Record<string, any> | undefined;
            animationThreshold?: number | undefined;
            animationDuration?: number | Function | undefined;
            animationEasing?: string | Function | undefined;
            animationDelay?: number | Function | undefined;
            animationDelayUpdate?: string | Function | undefined;
            backgroundColor?: unknown;
            textStyle?: Record<string, any> | undefined;
            options?: Record<string, any> | undefined;
            media?: unknown[] | undefined;
            settings?: unknown;
        }>, {
            option: EChartsOption;
            animation: boolean;
            darkMode: string | boolean;
            useUTC: boolean;
            variant: string;
            loading: boolean;
            emptyText: string;
        }>, EmitsOptions, string, {}>;
        $forceUpdate: ReactiveEffect<any>;
        $nextTick: typeof nextTick;
        $watch(source: string | Function, cb: Function, options?: WatchOptions<boolean> | undefined): WatchStopHandle;
    } & Readonly<{
        option: EChartsOption;
        animation: boolean;
        darkMode: string | boolean;
        useUTC: boolean;
        variant: string;
        loading: boolean;
        emptyText: string;
    } & {
        title?: TitleOption | undefined;
        legend?: LegendComponentOption | undefined;
        grid?: GridOption | undefined;
        xAxis?: XAXisOption | undefined;
        yAxis?: YAXisOption | undefined;
        polar?: PolarOption | undefined;
        radiusAxis?: RadiusAxisOption | undefined;
        angleAxis?: AngleAxisOption | undefined;
        radar?: RadarOption | undefined;
        dataZoom?: DataZoomComponentOption | undefined;
        visualMap?: VisualMapComponentOption | undefined;
        color?: unknown[] | undefined;
        toolbox?: ToolboxComponentOption | undefined;
        axisPointer?: AxisPointerOption | undefined;
        animationDurationUpdate?: number | Function | undefined;
        animationEasingUpdate?: string | Function | undefined;
        brush?: BrushOption | undefined;
        geo?: GeoOption | undefined;
        parallel?: ParallelCoordinateSystemOption | undefined;
        parallelAxis?: ParallelCoordinateSystemOption | undefined;
        singleAxis?: SingleAxisOption | undefined;
        timeline?: TimelineOption | undefined;
        graphic?: GraphicComponentLooseOption | undefined;
        tooltip?: ToolboxComponentOption | undefined;
        calendar?: CalendarOption | undefined;
        dataset?: DatasetOption | undefined;
        aria?: AriaOption | undefined;
        series?: SeriesOption | undefined;
        blendMode?: string | undefined;
        data?: unknown;
        hoverLayerThreshold?: number | undefined;
        stateAnimation?: Record<string, any> | undefined;
        animationThreshold?: number | undefined;
        animationDuration?: number | Function | undefined;
        animationEasing?: string | Function | undefined;
        animationDelay?: number | Function | undefined;
        animationDelayUpdate?: string | Function | undefined;
        backgroundColor?: unknown;
        textStyle?: Record<string, any> | undefined;
        options?: Record<string, any> | undefined;
        media?: unknown[] | undefined;
        settings?: unknown;
    }> & Readonly<{} & {}> & ShallowUnwrapRef<{}> & {
        initOptions: {
            renderer: string;
        };
        needUpdate: boolean;
        setOptionOpts: {};
        mergedOption: {};
    } & {
        chartOpts: Record<string, any>;
        isEmptyData: boolean;
    } & {
        mergePropsToOption(props: any): void;
        forcedUpdate(): void;
    } & ComponentCustomProperties;
    __isFragment?: undefined;
    __isTeleport?: undefined;
    __isSuspense?: undefined;
} & ComponentOptionsBase<Readonly<{} & {}>, void, {}, {}, {}, ComponentOptionsMixin, DefineComponent<{
    title: PropType<TitleOption>;
    legend: PropType<LegendComponentOption>;
    grid: PropType<GridOption>;
    xAxis: PropType<XAXisOption>;
    yAxis: PropType<YAXisOption>;
    polar: PropType<PolarOption>;
    radiusAxis: PropType<RadiusAxisOption>;
    angleAxis: PropType<AngleAxisOption>;
    radar: PropType<RadarOption>;
    dataZoom: PropType<DataZoomComponentOption>;
    visualMap: PropType<VisualMapComponentOption>;
    tooltip: PropType<ToolboxComponentOption>;
    axisPointer: PropType<AxisPointerOption>;
    toolbox: PropType<ToolboxComponentOption>;
    brush: PropType<BrushOption>;
    geo: PropType<GeoOption>;
    parallel: PropType<ParallelCoordinateSystemOption>;
    parallelAxis: PropType<ParallelCoordinateSystemOption>;
    singleAxis: PropType<SingleAxisOption>;
    timeline: PropType<TimelineOption>;
    graphic: PropType<GraphicComponentLooseOption>;
    calendar: PropType<CalendarOption>;
    dataset: PropType<DatasetOption>;
    aria: PropType<AriaOption>;
    series: PropType<SeriesOption>;
    darkMode: {
        type: (StringConstructor | BooleanConstructor)[];
        default: string;
    };
    color: ArrayConstructor;
    backgroundColor: (ObjectConstructor | StringConstructor)[];
    textStyle: ObjectConstructor;
    animation: {
        type: BooleanConstructor;
        default: boolean;
    };
    animationThreshold: NumberConstructor;
    animationDuration: (NumberConstructor | FunctionConstructor)[];
    animationEasing: (StringConstructor | FunctionConstructor)[];
    animationDelay: (NumberConstructor | FunctionConstructor)[];
    animationDurationUpdate: (NumberConstructor | FunctionConstructor)[];
    animationEasingUpdate: (StringConstructor | FunctionConstructor)[];
    animationDelayUpdate: (StringConstructor | FunctionConstructor)[];
    stateAnimation: ObjectConstructor;
    blendMode: StringConstructor;
    hoverLayerThreshold: NumberConstructor;
    useUTC: {
        type: BooleanConstructor;
        default: boolean;
    };
    options: ObjectConstructor;
    media: ArrayConstructor;
    data: (ObjectConstructor | ArrayConstructor)[];
    settings: (ObjectConstructor | ArrayConstructor)[];
    variant: {
        type: StringConstructor;
        default: string;
    };
    loading: {
        type: BooleanConstructor;
        default: boolean;
    };
    emptyText: {
        type: StringConstructor;
        default: string;
    };
    option: {
        type: PropType<EChartsOption>;
        default: () => {};
    };
}, unknown, {
    initOptions: {
        renderer: string;
    };
    needUpdate: boolean;
    setOptionOpts: {};
    mergedOption: {};
}, {
    chartOpts(): Record<string, any>;
    isEmptyData(): boolean;
}, {
    mergePropsToOption(props: any): void;
    forcedUpdate(): void;
}, ComponentOptionsMixin, ComponentOptionsMixin, Record<string, any>, string, VNodeProps & AllowedComponentProps & ComponentCustomProps, Readonly<{
    option: EChartsOption;
    animation: boolean;
    darkMode: string | boolean;
    useUTC: boolean;
    variant: string;
    loading: boolean;
    emptyText: string;
} & {
    title?: TitleOption | undefined;
    legend?: LegendComponentOption | undefined;
    grid?: GridOption | undefined;
    xAxis?: XAXisOption | undefined;
    yAxis?: YAXisOption | undefined;
    polar?: PolarOption | undefined;
    radiusAxis?: RadiusAxisOption | undefined;
    angleAxis?: AngleAxisOption | undefined;
    radar?: RadarOption | undefined;
    dataZoom?: DataZoomComponentOption | undefined;
    visualMap?: VisualMapComponentOption | undefined;
    color?: unknown[] | undefined;
    toolbox?: ToolboxComponentOption | undefined;
    axisPointer?: AxisPointerOption | undefined;
    animationDurationUpdate?: number | Function | undefined;
    animationEasingUpdate?: string | Function | undefined;
    brush?: BrushOption | undefined;
    geo?: GeoOption | undefined;
    parallel?: ParallelCoordinateSystemOption | undefined;
    parallelAxis?: ParallelCoordinateSystemOption | undefined;
    singleAxis?: SingleAxisOption | undefined;
    timeline?: TimelineOption | undefined;
    graphic?: GraphicComponentLooseOption | undefined;
    tooltip?: ToolboxComponentOption | undefined;
    calendar?: CalendarOption | undefined;
    dataset?: DatasetOption | undefined;
    aria?: AriaOption | undefined;
    series?: SeriesOption | undefined;
    blendMode?: string | undefined;
    data?: unknown;
    hoverLayerThreshold?: number | undefined;
    stateAnimation?: Record<string, any> | undefined;
    animationThreshold?: number | undefined;
    animationDuration?: number | Function | undefined;
    animationEasing?: string | Function | undefined;
    animationDelay?: number | Function | undefined;
    animationDelayUpdate?: string | Function | undefined;
    backgroundColor?: unknown;
    textStyle?: Record<string, any> | undefined;
    options?: Record<string, any> | undefined;
    media?: unknown[] | undefined;
    settings?: unknown;
}>, {
    option: EChartsOption;
    animation: boolean;
    darkMode: string | boolean;
    useUTC: boolean;
    variant: string;
    loading: boolean;
    emptyText: string;
}>, EmitsOptions, string, {}> & VNodeProps & AllowedComponentProps & ComponentCustomProps & {
    install(app: App<any>): void;
} & Plugin;

declare const GaugeChart: {
    new (...args: any[]): {
        $: ComponentInternalInstance;
        $data: {
            initOptions: {
                renderer: string;
            };
            needUpdate: boolean;
            setOptionOpts: {};
            mergedOption: {};
        };
        $props: Partial<{
            option: EChartsOption;
            animation: boolean;
            darkMode: string | boolean;
            useUTC: boolean;
            variant: string;
            loading: boolean;
            emptyText: string;
        } & {}> & Omit<Readonly<{
            option: EChartsOption;
            animation: boolean;
            darkMode: string | boolean;
            useUTC: boolean;
            variant: string;
            loading: boolean;
            emptyText: string;
        } & {
            title?: TitleOption | undefined;
            legend?: LegendComponentOption | undefined;
            grid?: GridOption | undefined;
            xAxis?: XAXisOption | undefined;
            yAxis?: YAXisOption | undefined;
            polar?: PolarOption | undefined;
            radiusAxis?: RadiusAxisOption | undefined;
            angleAxis?: AngleAxisOption | undefined;
            radar?: RadarOption | undefined;
            dataZoom?: DataZoomComponentOption | undefined;
            visualMap?: VisualMapComponentOption | undefined;
            color?: unknown[] | undefined;
            toolbox?: ToolboxComponentOption | undefined;
            axisPointer?: AxisPointerOption | undefined;
            animationDurationUpdate?: number | Function | undefined;
            animationEasingUpdate?: string | Function | undefined;
            brush?: BrushOption | undefined;
            geo?: GeoOption | undefined;
            parallel?: ParallelCoordinateSystemOption | undefined;
            parallelAxis?: ParallelCoordinateSystemOption | undefined;
            singleAxis?: SingleAxisOption | undefined;
            timeline?: TimelineOption | undefined;
            graphic?: GraphicComponentLooseOption | undefined;
            tooltip?: ToolboxComponentOption | undefined;
            calendar?: CalendarOption | undefined;
            dataset?: DatasetOption | undefined;
            aria?: AriaOption | undefined;
            series?: SeriesOption | undefined;
            blendMode?: string | undefined;
            data?: unknown;
            hoverLayerThreshold?: number | undefined;
            stateAnimation?: Record<string, any> | undefined;
            animationThreshold?: number | undefined;
            animationDuration?: number | Function | undefined;
            animationEasing?: string | Function | undefined;
            animationDelay?: number | Function | undefined;
            animationDelayUpdate?: string | Function | undefined;
            backgroundColor?: unknown;
            textStyle?: Record<string, any> | undefined;
            options?: Record<string, any> | undefined;
            media?: unknown[] | undefined;
            settings?: unknown;
        }> & Readonly<{} & {}> & VNodeProps & AllowedComponentProps & ComponentCustomProps, "option" | "animation" | "darkMode" | "useUTC" | "variant" | "loading" | "emptyText">;
        $attrs: {
            [x: string]: unknown;
        };
        $refs: {
            [x: string]: unknown;
        };
        $slots: Readonly<{
            [name: string]: Slot | undefined;
        }>;
        $root: ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}>> | null;
        $parent: ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}>> | null;
        $emit: ((event: string, ...args: any[]) => void) | ((event: string, ...args: any[]) => void);
        $el: any;
        $options: ComponentOptionsBase<Readonly<{} & {}>, void, {}, {}, {}, ComponentOptionsMixin, DefineComponent<{
            title: PropType<TitleOption>;
            legend: PropType<LegendComponentOption>;
            grid: PropType<GridOption>;
            xAxis: PropType<XAXisOption>;
            yAxis: PropType<YAXisOption>;
            polar: PropType<PolarOption>;
            radiusAxis: PropType<RadiusAxisOption>;
            angleAxis: PropType<AngleAxisOption>;
            radar: PropType<RadarOption>;
            dataZoom: PropType<DataZoomComponentOption>;
            visualMap: PropType<VisualMapComponentOption>;
            tooltip: PropType<ToolboxComponentOption>;
            axisPointer: PropType<AxisPointerOption>;
            toolbox: PropType<ToolboxComponentOption>;
            brush: PropType<BrushOption>;
            geo: PropType<GeoOption>;
            parallel: PropType<ParallelCoordinateSystemOption>;
            parallelAxis: PropType<ParallelCoordinateSystemOption>;
            singleAxis: PropType<SingleAxisOption>;
            timeline: PropType<TimelineOption>;
            graphic: PropType<GraphicComponentLooseOption>;
            calendar: PropType<CalendarOption>;
            dataset: PropType<DatasetOption>;
            aria: PropType<AriaOption>;
            series: PropType<SeriesOption>;
            darkMode: {
                type: (StringConstructor | BooleanConstructor)[];
                default: string;
            };
            color: ArrayConstructor;
            backgroundColor: (ObjectConstructor | StringConstructor)[];
            textStyle: ObjectConstructor;
            animation: {
                type: BooleanConstructor;
                default: boolean;
            };
            animationThreshold: NumberConstructor;
            animationDuration: (NumberConstructor | FunctionConstructor)[];
            animationEasing: (StringConstructor | FunctionConstructor)[];
            animationDelay: (NumberConstructor | FunctionConstructor)[];
            animationDurationUpdate: (NumberConstructor | FunctionConstructor)[];
            animationEasingUpdate: (StringConstructor | FunctionConstructor)[];
            animationDelayUpdate: (StringConstructor | FunctionConstructor)[];
            stateAnimation: ObjectConstructor;
            blendMode: StringConstructor;
            hoverLayerThreshold: NumberConstructor;
            useUTC: {
                type: BooleanConstructor;
                default: boolean;
            };
            options: ObjectConstructor;
            media: ArrayConstructor;
            data: (ObjectConstructor | ArrayConstructor)[];
            settings: (ObjectConstructor | ArrayConstructor)[];
            variant: {
                type: StringConstructor;
                default: string;
            };
            loading: {
                type: BooleanConstructor;
                default: boolean;
            };
            emptyText: {
                type: StringConstructor;
                default: string;
            };
            option: {
                type: PropType<EChartsOption>;
                default: () => {};
            };
        }, unknown, {
            initOptions: {
                renderer: string;
            };
            needUpdate: boolean;
            setOptionOpts: {};
            mergedOption: {};
        }, {
            chartOpts(): Record<string, any>;
            isEmptyData(): boolean;
        }, {
            mergePropsToOption(props: any): void;
            forcedUpdate(): void;
        }, ComponentOptionsMixin, ComponentOptionsMixin, Record<string, any>, string, VNodeProps & AllowedComponentProps & ComponentCustomProps, Readonly<{
            option: EChartsOption;
            animation: boolean;
            darkMode: string | boolean;
            useUTC: boolean;
            variant: string;
            loading: boolean;
            emptyText: string;
        } & {
            title?: TitleOption | undefined;
            legend?: LegendComponentOption | undefined;
            grid?: GridOption | undefined;
            xAxis?: XAXisOption | undefined;
            yAxis?: YAXisOption | undefined;
            polar?: PolarOption | undefined;
            radiusAxis?: RadiusAxisOption | undefined;
            angleAxis?: AngleAxisOption | undefined;
            radar?: RadarOption | undefined;
            dataZoom?: DataZoomComponentOption | undefined;
            visualMap?: VisualMapComponentOption | undefined;
            color?: unknown[] | undefined;
            toolbox?: ToolboxComponentOption | undefined;
            axisPointer?: AxisPointerOption | undefined;
            animationDurationUpdate?: number | Function | undefined;
            animationEasingUpdate?: string | Function | undefined;
            brush?: BrushOption | undefined;
            geo?: GeoOption | undefined;
            parallel?: ParallelCoordinateSystemOption | undefined;
            parallelAxis?: ParallelCoordinateSystemOption | undefined;
            singleAxis?: SingleAxisOption | undefined;
            timeline?: TimelineOption | undefined;
            graphic?: GraphicComponentLooseOption | undefined;
            tooltip?: ToolboxComponentOption | undefined;
            calendar?: CalendarOption | undefined;
            dataset?: DatasetOption | undefined;
            aria?: AriaOption | undefined;
            series?: SeriesOption | undefined;
            blendMode?: string | undefined;
            data?: unknown;
            hoverLayerThreshold?: number | undefined;
            stateAnimation?: Record<string, any> | undefined;
            animationThreshold?: number | undefined;
            animationDuration?: number | Function | undefined;
            animationEasing?: string | Function | undefined;
            animationDelay?: number | Function | undefined;
            animationDelayUpdate?: string | Function | undefined;
            backgroundColor?: unknown;
            textStyle?: Record<string, any> | undefined;
            options?: Record<string, any> | undefined;
            media?: unknown[] | undefined;
            settings?: unknown;
        }>, {
            option: EChartsOption;
            animation: boolean;
            darkMode: string | boolean;
            useUTC: boolean;
            variant: string;
            loading: boolean;
            emptyText: string;
        }>, EmitsOptions, string, {}>;
        $forceUpdate: ReactiveEffect<any>;
        $nextTick: typeof nextTick;
        $watch(source: string | Function, cb: Function, options?: WatchOptions<boolean> | undefined): WatchStopHandle;
    } & Readonly<{
        option: EChartsOption;
        animation: boolean;
        darkMode: string | boolean;
        useUTC: boolean;
        variant: string;
        loading: boolean;
        emptyText: string;
    } & {
        title?: TitleOption | undefined;
        legend?: LegendComponentOption | undefined;
        grid?: GridOption | undefined;
        xAxis?: XAXisOption | undefined;
        yAxis?: YAXisOption | undefined;
        polar?: PolarOption | undefined;
        radiusAxis?: RadiusAxisOption | undefined;
        angleAxis?: AngleAxisOption | undefined;
        radar?: RadarOption | undefined;
        dataZoom?: DataZoomComponentOption | undefined;
        visualMap?: VisualMapComponentOption | undefined;
        color?: unknown[] | undefined;
        toolbox?: ToolboxComponentOption | undefined;
        axisPointer?: AxisPointerOption | undefined;
        animationDurationUpdate?: number | Function | undefined;
        animationEasingUpdate?: string | Function | undefined;
        brush?: BrushOption | undefined;
        geo?: GeoOption | undefined;
        parallel?: ParallelCoordinateSystemOption | undefined;
        parallelAxis?: ParallelCoordinateSystemOption | undefined;
        singleAxis?: SingleAxisOption | undefined;
        timeline?: TimelineOption | undefined;
        graphic?: GraphicComponentLooseOption | undefined;
        tooltip?: ToolboxComponentOption | undefined;
        calendar?: CalendarOption | undefined;
        dataset?: DatasetOption | undefined;
        aria?: AriaOption | undefined;
        series?: SeriesOption | undefined;
        blendMode?: string | undefined;
        data?: unknown;
        hoverLayerThreshold?: number | undefined;
        stateAnimation?: Record<string, any> | undefined;
        animationThreshold?: number | undefined;
        animationDuration?: number | Function | undefined;
        animationEasing?: string | Function | undefined;
        animationDelay?: number | Function | undefined;
        animationDelayUpdate?: string | Function | undefined;
        backgroundColor?: unknown;
        textStyle?: Record<string, any> | undefined;
        options?: Record<string, any> | undefined;
        media?: unknown[] | undefined;
        settings?: unknown;
    }> & Readonly<{} & {}> & ShallowUnwrapRef<{}> & {
        initOptions: {
            renderer: string;
        };
        needUpdate: boolean;
        setOptionOpts: {};
        mergedOption: {};
    } & {
        chartOpts: Record<string, any>;
        isEmptyData: boolean;
    } & {
        mergePropsToOption(props: any): void;
        forcedUpdate(): void;
    } & ComponentCustomProperties;
    __isFragment?: undefined;
    __isTeleport?: undefined;
    __isSuspense?: undefined;
} & ComponentOptionsBase<Readonly<{} & {}>, void, {}, {}, {}, ComponentOptionsMixin, DefineComponent<{
    title: PropType<TitleOption>;
    legend: PropType<LegendComponentOption>;
    grid: PropType<GridOption>;
    xAxis: PropType<XAXisOption>;
    yAxis: PropType<YAXisOption>;
    polar: PropType<PolarOption>;
    radiusAxis: PropType<RadiusAxisOption>;
    angleAxis: PropType<AngleAxisOption>;
    radar: PropType<RadarOption>;
    dataZoom: PropType<DataZoomComponentOption>;
    visualMap: PropType<VisualMapComponentOption>;
    tooltip: PropType<ToolboxComponentOption>;
    axisPointer: PropType<AxisPointerOption>;
    toolbox: PropType<ToolboxComponentOption>;
    brush: PropType<BrushOption>;
    geo: PropType<GeoOption>;
    parallel: PropType<ParallelCoordinateSystemOption>;
    parallelAxis: PropType<ParallelCoordinateSystemOption>;
    singleAxis: PropType<SingleAxisOption>;
    timeline: PropType<TimelineOption>;
    graphic: PropType<GraphicComponentLooseOption>;
    calendar: PropType<CalendarOption>;
    dataset: PropType<DatasetOption>;
    aria: PropType<AriaOption>;
    series: PropType<SeriesOption>;
    darkMode: {
        type: (StringConstructor | BooleanConstructor)[];
        default: string;
    };
    color: ArrayConstructor;
    backgroundColor: (ObjectConstructor | StringConstructor)[];
    textStyle: ObjectConstructor;
    animation: {
        type: BooleanConstructor;
        default: boolean;
    };
    animationThreshold: NumberConstructor;
    animationDuration: (NumberConstructor | FunctionConstructor)[];
    animationEasing: (StringConstructor | FunctionConstructor)[];
    animationDelay: (NumberConstructor | FunctionConstructor)[];
    animationDurationUpdate: (NumberConstructor | FunctionConstructor)[];
    animationEasingUpdate: (StringConstructor | FunctionConstructor)[];
    animationDelayUpdate: (StringConstructor | FunctionConstructor)[];
    stateAnimation: ObjectConstructor;
    blendMode: StringConstructor;
    hoverLayerThreshold: NumberConstructor;
    useUTC: {
        type: BooleanConstructor;
        default: boolean;
    };
    options: ObjectConstructor;
    media: ArrayConstructor;
    data: (ObjectConstructor | ArrayConstructor)[];
    settings: (ObjectConstructor | ArrayConstructor)[];
    variant: {
        type: StringConstructor;
        default: string;
    };
    loading: {
        type: BooleanConstructor;
        default: boolean;
    };
    emptyText: {
        type: StringConstructor;
        default: string;
    };
    option: {
        type: PropType<EChartsOption>;
        default: () => {};
    };
}, unknown, {
    initOptions: {
        renderer: string;
    };
    needUpdate: boolean;
    setOptionOpts: {};
    mergedOption: {};
}, {
    chartOpts(): Record<string, any>;
    isEmptyData(): boolean;
}, {
    mergePropsToOption(props: any): void;
    forcedUpdate(): void;
}, ComponentOptionsMixin, ComponentOptionsMixin, Record<string, any>, string, VNodeProps & AllowedComponentProps & ComponentCustomProps, Readonly<{
    option: EChartsOption;
    animation: boolean;
    darkMode: string | boolean;
    useUTC: boolean;
    variant: string;
    loading: boolean;
    emptyText: string;
} & {
    title?: TitleOption | undefined;
    legend?: LegendComponentOption | undefined;
    grid?: GridOption | undefined;
    xAxis?: XAXisOption | undefined;
    yAxis?: YAXisOption | undefined;
    polar?: PolarOption | undefined;
    radiusAxis?: RadiusAxisOption | undefined;
    angleAxis?: AngleAxisOption | undefined;
    radar?: RadarOption | undefined;
    dataZoom?: DataZoomComponentOption | undefined;
    visualMap?: VisualMapComponentOption | undefined;
    color?: unknown[] | undefined;
    toolbox?: ToolboxComponentOption | undefined;
    axisPointer?: AxisPointerOption | undefined;
    animationDurationUpdate?: number | Function | undefined;
    animationEasingUpdate?: string | Function | undefined;
    brush?: BrushOption | undefined;
    geo?: GeoOption | undefined;
    parallel?: ParallelCoordinateSystemOption | undefined;
    parallelAxis?: ParallelCoordinateSystemOption | undefined;
    singleAxis?: SingleAxisOption | undefined;
    timeline?: TimelineOption | undefined;
    graphic?: GraphicComponentLooseOption | undefined;
    tooltip?: ToolboxComponentOption | undefined;
    calendar?: CalendarOption | undefined;
    dataset?: DatasetOption | undefined;
    aria?: AriaOption | undefined;
    series?: SeriesOption | undefined;
    blendMode?: string | undefined;
    data?: unknown;
    hoverLayerThreshold?: number | undefined;
    stateAnimation?: Record<string, any> | undefined;
    animationThreshold?: number | undefined;
    animationDuration?: number | Function | undefined;
    animationEasing?: string | Function | undefined;
    animationDelay?: number | Function | undefined;
    animationDelayUpdate?: string | Function | undefined;
    backgroundColor?: unknown;
    textStyle?: Record<string, any> | undefined;
    options?: Record<string, any> | undefined;
    media?: unknown[] | undefined;
    settings?: unknown;
}>, {
    option: EChartsOption;
    animation: boolean;
    darkMode: string | boolean;
    useUTC: boolean;
    variant: string;
    loading: boolean;
    emptyText: string;
}>, EmitsOptions, string, {}> & VNodeProps & AllowedComponentProps & ComponentCustomProps & {
    install(app: App<any>): void;
} & Plugin;

declare const RadarChart: {
    new (...args: any[]): {
        $: ComponentInternalInstance;
        $data: {
            initOptions: {
                renderer: string;
            };
            needUpdate: boolean;
            setOptionOpts: {};
            mergedOption: {};
        };
        $props: Partial<{
            option: EChartsOption;
            animation: boolean;
            darkMode: string | boolean;
            useUTC: boolean;
            variant: string;
            loading: boolean;
            emptyText: string;
        } & {}> & Omit<Readonly<{
            option: EChartsOption;
            animation: boolean;
            darkMode: string | boolean;
            useUTC: boolean;
            variant: string;
            loading: boolean;
            emptyText: string;
        } & {
            title?: TitleOption | undefined;
            legend?: LegendComponentOption | undefined;
            grid?: GridOption | undefined;
            xAxis?: XAXisOption | undefined;
            yAxis?: YAXisOption | undefined;
            polar?: PolarOption | undefined;
            radiusAxis?: RadiusAxisOption | undefined;
            angleAxis?: AngleAxisOption | undefined;
            radar?: RadarOption | undefined;
            dataZoom?: DataZoomComponentOption | undefined;
            visualMap?: VisualMapComponentOption | undefined;
            color?: unknown[] | undefined;
            toolbox?: ToolboxComponentOption | undefined;
            axisPointer?: AxisPointerOption | undefined;
            animationDurationUpdate?: number | Function | undefined;
            animationEasingUpdate?: string | Function | undefined;
            brush?: BrushOption | undefined;
            geo?: GeoOption | undefined;
            parallel?: ParallelCoordinateSystemOption | undefined;
            parallelAxis?: ParallelCoordinateSystemOption | undefined;
            singleAxis?: SingleAxisOption | undefined;
            timeline?: TimelineOption | undefined;
            graphic?: GraphicComponentLooseOption | undefined;
            tooltip?: ToolboxComponentOption | undefined;
            calendar?: CalendarOption | undefined;
            dataset?: DatasetOption | undefined;
            aria?: AriaOption | undefined;
            series?: SeriesOption | undefined;
            blendMode?: string | undefined;
            data?: unknown;
            hoverLayerThreshold?: number | undefined;
            stateAnimation?: Record<string, any> | undefined;
            animationThreshold?: number | undefined;
            animationDuration?: number | Function | undefined;
            animationEasing?: string | Function | undefined;
            animationDelay?: number | Function | undefined;
            animationDelayUpdate?: string | Function | undefined;
            backgroundColor?: unknown;
            textStyle?: Record<string, any> | undefined;
            options?: Record<string, any> | undefined;
            media?: unknown[] | undefined;
            settings?: unknown;
        }> & Readonly<{} & {}> & VNodeProps & AllowedComponentProps & ComponentCustomProps, "option" | "animation" | "darkMode" | "useUTC" | "variant" | "loading" | "emptyText">;
        $attrs: {
            [x: string]: unknown;
        };
        $refs: {
            [x: string]: unknown;
        };
        $slots: Readonly<{
            [name: string]: Slot | undefined;
        }>;
        $root: ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}>> | null;
        $parent: ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}>> | null;
        $emit: ((event: string, ...args: any[]) => void) | ((event: string, ...args: any[]) => void);
        $el: any;
        $options: ComponentOptionsBase<Readonly<{} & {}>, void, {}, {}, {}, ComponentOptionsMixin, DefineComponent<{
            title: PropType<TitleOption>;
            legend: PropType<LegendComponentOption>;
            grid: PropType<GridOption>;
            xAxis: PropType<XAXisOption>;
            yAxis: PropType<YAXisOption>;
            polar: PropType<PolarOption>;
            radiusAxis: PropType<RadiusAxisOption>;
            angleAxis: PropType<AngleAxisOption>;
            radar: PropType<RadarOption>;
            dataZoom: PropType<DataZoomComponentOption>;
            visualMap: PropType<VisualMapComponentOption>;
            tooltip: PropType<ToolboxComponentOption>;
            axisPointer: PropType<AxisPointerOption>;
            toolbox: PropType<ToolboxComponentOption>;
            brush: PropType<BrushOption>;
            geo: PropType<GeoOption>;
            parallel: PropType<ParallelCoordinateSystemOption>;
            parallelAxis: PropType<ParallelCoordinateSystemOption>;
            singleAxis: PropType<SingleAxisOption>;
            timeline: PropType<TimelineOption>;
            graphic: PropType<GraphicComponentLooseOption>;
            calendar: PropType<CalendarOption>;
            dataset: PropType<DatasetOption>;
            aria: PropType<AriaOption>;
            series: PropType<SeriesOption>;
            darkMode: {
                type: (StringConstructor | BooleanConstructor)[];
                default: string;
            };
            color: ArrayConstructor;
            backgroundColor: (ObjectConstructor | StringConstructor)[];
            textStyle: ObjectConstructor;
            animation: {
                type: BooleanConstructor;
                default: boolean;
            };
            animationThreshold: NumberConstructor;
            animationDuration: (NumberConstructor | FunctionConstructor)[];
            animationEasing: (StringConstructor | FunctionConstructor)[];
            animationDelay: (NumberConstructor | FunctionConstructor)[];
            animationDurationUpdate: (NumberConstructor | FunctionConstructor)[];
            animationEasingUpdate: (StringConstructor | FunctionConstructor)[];
            animationDelayUpdate: (StringConstructor | FunctionConstructor)[];
            stateAnimation: ObjectConstructor;
            blendMode: StringConstructor;
            hoverLayerThreshold: NumberConstructor;
            useUTC: {
                type: BooleanConstructor;
                default: boolean;
            };
            options: ObjectConstructor;
            media: ArrayConstructor;
            data: (ObjectConstructor | ArrayConstructor)[];
            settings: (ObjectConstructor | ArrayConstructor)[];
            variant: {
                type: StringConstructor;
                default: string;
            };
            loading: {
                type: BooleanConstructor;
                default: boolean;
            };
            emptyText: {
                type: StringConstructor;
                default: string;
            };
            option: {
                type: PropType<EChartsOption>;
                default: () => {};
            };
        }, unknown, {
            initOptions: {
                renderer: string;
            };
            needUpdate: boolean;
            setOptionOpts: {};
            mergedOption: {};
        }, {
            chartOpts(): Record<string, any>;
            isEmptyData(): boolean;
        }, {
            mergePropsToOption(props: any): void;
            forcedUpdate(): void;
        }, ComponentOptionsMixin, ComponentOptionsMixin, Record<string, any>, string, VNodeProps & AllowedComponentProps & ComponentCustomProps, Readonly<{
            option: EChartsOption;
            animation: boolean;
            darkMode: string | boolean;
            useUTC: boolean;
            variant: string;
            loading: boolean;
            emptyText: string;
        } & {
            title?: TitleOption | undefined;
            legend?: LegendComponentOption | undefined;
            grid?: GridOption | undefined;
            xAxis?: XAXisOption | undefined;
            yAxis?: YAXisOption | undefined;
            polar?: PolarOption | undefined;
            radiusAxis?: RadiusAxisOption | undefined;
            angleAxis?: AngleAxisOption | undefined;
            radar?: RadarOption | undefined;
            dataZoom?: DataZoomComponentOption | undefined;
            visualMap?: VisualMapComponentOption | undefined;
            color?: unknown[] | undefined;
            toolbox?: ToolboxComponentOption | undefined;
            axisPointer?: AxisPointerOption | undefined;
            animationDurationUpdate?: number | Function | undefined;
            animationEasingUpdate?: string | Function | undefined;
            brush?: BrushOption | undefined;
            geo?: GeoOption | undefined;
            parallel?: ParallelCoordinateSystemOption | undefined;
            parallelAxis?: ParallelCoordinateSystemOption | undefined;
            singleAxis?: SingleAxisOption | undefined;
            timeline?: TimelineOption | undefined;
            graphic?: GraphicComponentLooseOption | undefined;
            tooltip?: ToolboxComponentOption | undefined;
            calendar?: CalendarOption | undefined;
            dataset?: DatasetOption | undefined;
            aria?: AriaOption | undefined;
            series?: SeriesOption | undefined;
            blendMode?: string | undefined;
            data?: unknown;
            hoverLayerThreshold?: number | undefined;
            stateAnimation?: Record<string, any> | undefined;
            animationThreshold?: number | undefined;
            animationDuration?: number | Function | undefined;
            animationEasing?: string | Function | undefined;
            animationDelay?: number | Function | undefined;
            animationDelayUpdate?: string | Function | undefined;
            backgroundColor?: unknown;
            textStyle?: Record<string, any> | undefined;
            options?: Record<string, any> | undefined;
            media?: unknown[] | undefined;
            settings?: unknown;
        }>, {
            option: EChartsOption;
            animation: boolean;
            darkMode: string | boolean;
            useUTC: boolean;
            variant: string;
            loading: boolean;
            emptyText: string;
        }>, EmitsOptions, string, {}>;
        $forceUpdate: ReactiveEffect<any>;
        $nextTick: typeof nextTick;
        $watch(source: string | Function, cb: Function, options?: WatchOptions<boolean> | undefined): WatchStopHandle;
    } & Readonly<{
        option: EChartsOption;
        animation: boolean;
        darkMode: string | boolean;
        useUTC: boolean;
        variant: string;
        loading: boolean;
        emptyText: string;
    } & {
        title?: TitleOption | undefined;
        legend?: LegendComponentOption | undefined;
        grid?: GridOption | undefined;
        xAxis?: XAXisOption | undefined;
        yAxis?: YAXisOption | undefined;
        polar?: PolarOption | undefined;
        radiusAxis?: RadiusAxisOption | undefined;
        angleAxis?: AngleAxisOption | undefined;
        radar?: RadarOption | undefined;
        dataZoom?: DataZoomComponentOption | undefined;
        visualMap?: VisualMapComponentOption | undefined;
        color?: unknown[] | undefined;
        toolbox?: ToolboxComponentOption | undefined;
        axisPointer?: AxisPointerOption | undefined;
        animationDurationUpdate?: number | Function | undefined;
        animationEasingUpdate?: string | Function | undefined;
        brush?: BrushOption | undefined;
        geo?: GeoOption | undefined;
        parallel?: ParallelCoordinateSystemOption | undefined;
        parallelAxis?: ParallelCoordinateSystemOption | undefined;
        singleAxis?: SingleAxisOption | undefined;
        timeline?: TimelineOption | undefined;
        graphic?: GraphicComponentLooseOption | undefined;
        tooltip?: ToolboxComponentOption | undefined;
        calendar?: CalendarOption | undefined;
        dataset?: DatasetOption | undefined;
        aria?: AriaOption | undefined;
        series?: SeriesOption | undefined;
        blendMode?: string | undefined;
        data?: unknown;
        hoverLayerThreshold?: number | undefined;
        stateAnimation?: Record<string, any> | undefined;
        animationThreshold?: number | undefined;
        animationDuration?: number | Function | undefined;
        animationEasing?: string | Function | undefined;
        animationDelay?: number | Function | undefined;
        animationDelayUpdate?: string | Function | undefined;
        backgroundColor?: unknown;
        textStyle?: Record<string, any> | undefined;
        options?: Record<string, any> | undefined;
        media?: unknown[] | undefined;
        settings?: unknown;
    }> & Readonly<{} & {}> & ShallowUnwrapRef<{}> & {
        initOptions: {
            renderer: string;
        };
        needUpdate: boolean;
        setOptionOpts: {};
        mergedOption: {};
    } & {
        chartOpts: Record<string, any>;
        isEmptyData: boolean;
    } & {
        mergePropsToOption(props: any): void;
        forcedUpdate(): void;
    } & ComponentCustomProperties;
    __isFragment?: undefined;
    __isTeleport?: undefined;
    __isSuspense?: undefined;
} & ComponentOptionsBase<Readonly<{} & {}>, void, {}, {}, {}, ComponentOptionsMixin, DefineComponent<{
    title: PropType<TitleOption>;
    legend: PropType<LegendComponentOption>;
    grid: PropType<GridOption>;
    xAxis: PropType<XAXisOption>;
    yAxis: PropType<YAXisOption>;
    polar: PropType<PolarOption>;
    radiusAxis: PropType<RadiusAxisOption>;
    angleAxis: PropType<AngleAxisOption>;
    radar: PropType<RadarOption>;
    dataZoom: PropType<DataZoomComponentOption>;
    visualMap: PropType<VisualMapComponentOption>;
    tooltip: PropType<ToolboxComponentOption>;
    axisPointer: PropType<AxisPointerOption>;
    toolbox: PropType<ToolboxComponentOption>;
    brush: PropType<BrushOption>;
    geo: PropType<GeoOption>;
    parallel: PropType<ParallelCoordinateSystemOption>;
    parallelAxis: PropType<ParallelCoordinateSystemOption>;
    singleAxis: PropType<SingleAxisOption>;
    timeline: PropType<TimelineOption>;
    graphic: PropType<GraphicComponentLooseOption>;
    calendar: PropType<CalendarOption>;
    dataset: PropType<DatasetOption>;
    aria: PropType<AriaOption>;
    series: PropType<SeriesOption>;
    darkMode: {
        type: (StringConstructor | BooleanConstructor)[];
        default: string;
    };
    color: ArrayConstructor;
    backgroundColor: (ObjectConstructor | StringConstructor)[];
    textStyle: ObjectConstructor;
    animation: {
        type: BooleanConstructor;
        default: boolean;
    };
    animationThreshold: NumberConstructor;
    animationDuration: (NumberConstructor | FunctionConstructor)[];
    animationEasing: (StringConstructor | FunctionConstructor)[];
    animationDelay: (NumberConstructor | FunctionConstructor)[];
    animationDurationUpdate: (NumberConstructor | FunctionConstructor)[];
    animationEasingUpdate: (StringConstructor | FunctionConstructor)[];
    animationDelayUpdate: (StringConstructor | FunctionConstructor)[];
    stateAnimation: ObjectConstructor;
    blendMode: StringConstructor;
    hoverLayerThreshold: NumberConstructor;
    useUTC: {
        type: BooleanConstructor;
        default: boolean;
    };
    options: ObjectConstructor;
    media: ArrayConstructor;
    data: (ObjectConstructor | ArrayConstructor)[];
    settings: (ObjectConstructor | ArrayConstructor)[];
    variant: {
        type: StringConstructor;
        default: string;
    };
    loading: {
        type: BooleanConstructor;
        default: boolean;
    };
    emptyText: {
        type: StringConstructor;
        default: string;
    };
    option: {
        type: PropType<EChartsOption>;
        default: () => {};
    };
}, unknown, {
    initOptions: {
        renderer: string;
    };
    needUpdate: boolean;
    setOptionOpts: {};
    mergedOption: {};
}, {
    chartOpts(): Record<string, any>;
    isEmptyData(): boolean;
}, {
    mergePropsToOption(props: any): void;
    forcedUpdate(): void;
}, ComponentOptionsMixin, ComponentOptionsMixin, Record<string, any>, string, VNodeProps & AllowedComponentProps & ComponentCustomProps, Readonly<{
    option: EChartsOption;
    animation: boolean;
    darkMode: string | boolean;
    useUTC: boolean;
    variant: string;
    loading: boolean;
    emptyText: string;
} & {
    title?: TitleOption | undefined;
    legend?: LegendComponentOption | undefined;
    grid?: GridOption | undefined;
    xAxis?: XAXisOption | undefined;
    yAxis?: YAXisOption | undefined;
    polar?: PolarOption | undefined;
    radiusAxis?: RadiusAxisOption | undefined;
    angleAxis?: AngleAxisOption | undefined;
    radar?: RadarOption | undefined;
    dataZoom?: DataZoomComponentOption | undefined;
    visualMap?: VisualMapComponentOption | undefined;
    color?: unknown[] | undefined;
    toolbox?: ToolboxComponentOption | undefined;
    axisPointer?: AxisPointerOption | undefined;
    animationDurationUpdate?: number | Function | undefined;
    animationEasingUpdate?: string | Function | undefined;
    brush?: BrushOption | undefined;
    geo?: GeoOption | undefined;
    parallel?: ParallelCoordinateSystemOption | undefined;
    parallelAxis?: ParallelCoordinateSystemOption | undefined;
    singleAxis?: SingleAxisOption | undefined;
    timeline?: TimelineOption | undefined;
    graphic?: GraphicComponentLooseOption | undefined;
    tooltip?: ToolboxComponentOption | undefined;
    calendar?: CalendarOption | undefined;
    dataset?: DatasetOption | undefined;
    aria?: AriaOption | undefined;
    series?: SeriesOption | undefined;
    blendMode?: string | undefined;
    data?: unknown;
    hoverLayerThreshold?: number | undefined;
    stateAnimation?: Record<string, any> | undefined;
    animationThreshold?: number | undefined;
    animationDuration?: number | Function | undefined;
    animationEasing?: string | Function | undefined;
    animationDelay?: number | Function | undefined;
    animationDelayUpdate?: string | Function | undefined;
    backgroundColor?: unknown;
    textStyle?: Record<string, any> | undefined;
    options?: Record<string, any> | undefined;
    media?: unknown[] | undefined;
    settings?: unknown;
}>, {
    option: EChartsOption;
    animation: boolean;
    darkMode: string | boolean;
    useUTC: boolean;
    variant: string;
    loading: boolean;
    emptyText: string;
}>, EmitsOptions, string, {}> & VNodeProps & AllowedComponentProps & ComponentCustomProps & {
    install(app: App<any>): void;
} & Plugin;

declare const ScatterChart: {
    new (...args: any[]): {
        $: ComponentInternalInstance;
        $data: {
            initOptions: {
                renderer: string;
            };
            needUpdate: boolean;
            setOptionOpts: {};
            mergedOption: {};
        };
        $props: Partial<{
            option: EChartsOption;
            animation: boolean;
            darkMode: string | boolean;
            useUTC: boolean;
            variant: string;
            loading: boolean;
            emptyText: string;
        } & {}> & Omit<Readonly<{
            option: EChartsOption;
            animation: boolean;
            darkMode: string | boolean;
            useUTC: boolean;
            variant: string;
            loading: boolean;
            emptyText: string;
        } & {
            title?: TitleOption | undefined;
            legend?: LegendComponentOption | undefined;
            grid?: GridOption | undefined;
            xAxis?: XAXisOption | undefined;
            yAxis?: YAXisOption | undefined;
            polar?: PolarOption | undefined;
            radiusAxis?: RadiusAxisOption | undefined;
            angleAxis?: AngleAxisOption | undefined;
            radar?: RadarOption | undefined;
            dataZoom?: DataZoomComponentOption | undefined;
            visualMap?: VisualMapComponentOption | undefined;
            color?: unknown[] | undefined;
            toolbox?: ToolboxComponentOption | undefined;
            axisPointer?: AxisPointerOption | undefined;
            animationDurationUpdate?: number | Function | undefined;
            animationEasingUpdate?: string | Function | undefined;
            brush?: BrushOption | undefined;
            geo?: GeoOption | undefined;
            parallel?: ParallelCoordinateSystemOption | undefined;
            parallelAxis?: ParallelCoordinateSystemOption | undefined;
            singleAxis?: SingleAxisOption | undefined;
            timeline?: TimelineOption | undefined;
            graphic?: GraphicComponentLooseOption | undefined;
            tooltip?: ToolboxComponentOption | undefined;
            calendar?: CalendarOption | undefined;
            dataset?: DatasetOption | undefined;
            aria?: AriaOption | undefined;
            series?: SeriesOption | undefined;
            blendMode?: string | undefined;
            data?: unknown;
            hoverLayerThreshold?: number | undefined;
            stateAnimation?: Record<string, any> | undefined;
            animationThreshold?: number | undefined;
            animationDuration?: number | Function | undefined;
            animationEasing?: string | Function | undefined;
            animationDelay?: number | Function | undefined;
            animationDelayUpdate?: string | Function | undefined;
            backgroundColor?: unknown;
            textStyle?: Record<string, any> | undefined;
            options?: Record<string, any> | undefined;
            media?: unknown[] | undefined;
            settings?: unknown;
        }> & Readonly<{} & {}> & VNodeProps & AllowedComponentProps & ComponentCustomProps, "option" | "animation" | "darkMode" | "useUTC" | "variant" | "loading" | "emptyText">;
        $attrs: {
            [x: string]: unknown;
        };
        $refs: {
            [x: string]: unknown;
        };
        $slots: Readonly<{
            [name: string]: Slot | undefined;
        }>;
        $root: ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}>> | null;
        $parent: ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}>> | null;
        $emit: ((event: string, ...args: any[]) => void) | ((event: string, ...args: any[]) => void);
        $el: any;
        $options: ComponentOptionsBase<Readonly<{} & {}>, void, {}, {}, {}, ComponentOptionsMixin, DefineComponent<{
            title: PropType<TitleOption>;
            legend: PropType<LegendComponentOption>;
            grid: PropType<GridOption>;
            xAxis: PropType<XAXisOption>;
            yAxis: PropType<YAXisOption>;
            polar: PropType<PolarOption>;
            radiusAxis: PropType<RadiusAxisOption>;
            angleAxis: PropType<AngleAxisOption>;
            radar: PropType<RadarOption>;
            dataZoom: PropType<DataZoomComponentOption>;
            visualMap: PropType<VisualMapComponentOption>;
            tooltip: PropType<ToolboxComponentOption>;
            axisPointer: PropType<AxisPointerOption>;
            toolbox: PropType<ToolboxComponentOption>;
            brush: PropType<BrushOption>;
            geo: PropType<GeoOption>;
            parallel: PropType<ParallelCoordinateSystemOption>;
            parallelAxis: PropType<ParallelCoordinateSystemOption>;
            singleAxis: PropType<SingleAxisOption>;
            timeline: PropType<TimelineOption>;
            graphic: PropType<GraphicComponentLooseOption>;
            calendar: PropType<CalendarOption>;
            dataset: PropType<DatasetOption>;
            aria: PropType<AriaOption>;
            series: PropType<SeriesOption>;
            darkMode: {
                type: (StringConstructor | BooleanConstructor)[];
                default: string;
            };
            color: ArrayConstructor;
            backgroundColor: (ObjectConstructor | StringConstructor)[];
            textStyle: ObjectConstructor;
            animation: {
                type: BooleanConstructor;
                default: boolean;
            };
            animationThreshold: NumberConstructor;
            animationDuration: (NumberConstructor | FunctionConstructor)[];
            animationEasing: (StringConstructor | FunctionConstructor)[];
            animationDelay: (NumberConstructor | FunctionConstructor)[];
            animationDurationUpdate: (NumberConstructor | FunctionConstructor)[];
            animationEasingUpdate: (StringConstructor | FunctionConstructor)[];
            animationDelayUpdate: (StringConstructor | FunctionConstructor)[];
            stateAnimation: ObjectConstructor;
            blendMode: StringConstructor;
            hoverLayerThreshold: NumberConstructor;
            useUTC: {
                type: BooleanConstructor;
                default: boolean;
            };
            options: ObjectConstructor;
            media: ArrayConstructor;
            data: (ObjectConstructor | ArrayConstructor)[];
            settings: (ObjectConstructor | ArrayConstructor)[];
            variant: {
                type: StringConstructor;
                default: string;
            };
            loading: {
                type: BooleanConstructor;
                default: boolean;
            };
            emptyText: {
                type: StringConstructor;
                default: string;
            };
            option: {
                type: PropType<EChartsOption>;
                default: () => {};
            };
        }, unknown, {
            initOptions: {
                renderer: string;
            };
            needUpdate: boolean;
            setOptionOpts: {};
            mergedOption: {};
        }, {
            chartOpts(): Record<string, any>;
            isEmptyData(): boolean;
        }, {
            mergePropsToOption(props: any): void;
            forcedUpdate(): void;
        }, ComponentOptionsMixin, ComponentOptionsMixin, Record<string, any>, string, VNodeProps & AllowedComponentProps & ComponentCustomProps, Readonly<{
            option: EChartsOption;
            animation: boolean;
            darkMode: string | boolean;
            useUTC: boolean;
            variant: string;
            loading: boolean;
            emptyText: string;
        } & {
            title?: TitleOption | undefined;
            legend?: LegendComponentOption | undefined;
            grid?: GridOption | undefined;
            xAxis?: XAXisOption | undefined;
            yAxis?: YAXisOption | undefined;
            polar?: PolarOption | undefined;
            radiusAxis?: RadiusAxisOption | undefined;
            angleAxis?: AngleAxisOption | undefined;
            radar?: RadarOption | undefined;
            dataZoom?: DataZoomComponentOption | undefined;
            visualMap?: VisualMapComponentOption | undefined;
            color?: unknown[] | undefined;
            toolbox?: ToolboxComponentOption | undefined;
            axisPointer?: AxisPointerOption | undefined;
            animationDurationUpdate?: number | Function | undefined;
            animationEasingUpdate?: string | Function | undefined;
            brush?: BrushOption | undefined;
            geo?: GeoOption | undefined;
            parallel?: ParallelCoordinateSystemOption | undefined;
            parallelAxis?: ParallelCoordinateSystemOption | undefined;
            singleAxis?: SingleAxisOption | undefined;
            timeline?: TimelineOption | undefined;
            graphic?: GraphicComponentLooseOption | undefined;
            tooltip?: ToolboxComponentOption | undefined;
            calendar?: CalendarOption | undefined;
            dataset?: DatasetOption | undefined;
            aria?: AriaOption | undefined;
            series?: SeriesOption | undefined;
            blendMode?: string | undefined;
            data?: unknown;
            hoverLayerThreshold?: number | undefined;
            stateAnimation?: Record<string, any> | undefined;
            animationThreshold?: number | undefined;
            animationDuration?: number | Function | undefined;
            animationEasing?: string | Function | undefined;
            animationDelay?: number | Function | undefined;
            animationDelayUpdate?: string | Function | undefined;
            backgroundColor?: unknown;
            textStyle?: Record<string, any> | undefined;
            options?: Record<string, any> | undefined;
            media?: unknown[] | undefined;
            settings?: unknown;
        }>, {
            option: EChartsOption;
            animation: boolean;
            darkMode: string | boolean;
            useUTC: boolean;
            variant: string;
            loading: boolean;
            emptyText: string;
        }>, EmitsOptions, string, {}>;
        $forceUpdate: ReactiveEffect<any>;
        $nextTick: typeof nextTick;
        $watch(source: string | Function, cb: Function, options?: WatchOptions<boolean> | undefined): WatchStopHandle;
    } & Readonly<{
        option: EChartsOption;
        animation: boolean;
        darkMode: string | boolean;
        useUTC: boolean;
        variant: string;
        loading: boolean;
        emptyText: string;
    } & {
        title?: TitleOption | undefined;
        legend?: LegendComponentOption | undefined;
        grid?: GridOption | undefined;
        xAxis?: XAXisOption | undefined;
        yAxis?: YAXisOption | undefined;
        polar?: PolarOption | undefined;
        radiusAxis?: RadiusAxisOption | undefined;
        angleAxis?: AngleAxisOption | undefined;
        radar?: RadarOption | undefined;
        dataZoom?: DataZoomComponentOption | undefined;
        visualMap?: VisualMapComponentOption | undefined;
        color?: unknown[] | undefined;
        toolbox?: ToolboxComponentOption | undefined;
        axisPointer?: AxisPointerOption | undefined;
        animationDurationUpdate?: number | Function | undefined;
        animationEasingUpdate?: string | Function | undefined;
        brush?: BrushOption | undefined;
        geo?: GeoOption | undefined;
        parallel?: ParallelCoordinateSystemOption | undefined;
        parallelAxis?: ParallelCoordinateSystemOption | undefined;
        singleAxis?: SingleAxisOption | undefined;
        timeline?: TimelineOption | undefined;
        graphic?: GraphicComponentLooseOption | undefined;
        tooltip?: ToolboxComponentOption | undefined;
        calendar?: CalendarOption | undefined;
        dataset?: DatasetOption | undefined;
        aria?: AriaOption | undefined;
        series?: SeriesOption | undefined;
        blendMode?: string | undefined;
        data?: unknown;
        hoverLayerThreshold?: number | undefined;
        stateAnimation?: Record<string, any> | undefined;
        animationThreshold?: number | undefined;
        animationDuration?: number | Function | undefined;
        animationEasing?: string | Function | undefined;
        animationDelay?: number | Function | undefined;
        animationDelayUpdate?: string | Function | undefined;
        backgroundColor?: unknown;
        textStyle?: Record<string, any> | undefined;
        options?: Record<string, any> | undefined;
        media?: unknown[] | undefined;
        settings?: unknown;
    }> & Readonly<{} & {}> & ShallowUnwrapRef<{}> & {
        initOptions: {
            renderer: string;
        };
        needUpdate: boolean;
        setOptionOpts: {};
        mergedOption: {};
    } & {
        chartOpts: Record<string, any>;
        isEmptyData: boolean;
    } & {
        mergePropsToOption(props: any): void;
        forcedUpdate(): void;
    } & ComponentCustomProperties;
    __isFragment?: undefined;
    __isTeleport?: undefined;
    __isSuspense?: undefined;
} & ComponentOptionsBase<Readonly<{} & {}>, void, {}, {}, {}, ComponentOptionsMixin, DefineComponent<{
    title: PropType<TitleOption>;
    legend: PropType<LegendComponentOption>;
    grid: PropType<GridOption>;
    xAxis: PropType<XAXisOption>;
    yAxis: PropType<YAXisOption>;
    polar: PropType<PolarOption>;
    radiusAxis: PropType<RadiusAxisOption>;
    angleAxis: PropType<AngleAxisOption>;
    radar: PropType<RadarOption>;
    dataZoom: PropType<DataZoomComponentOption>;
    visualMap: PropType<VisualMapComponentOption>;
    tooltip: PropType<ToolboxComponentOption>;
    axisPointer: PropType<AxisPointerOption>;
    toolbox: PropType<ToolboxComponentOption>;
    brush: PropType<BrushOption>;
    geo: PropType<GeoOption>;
    parallel: PropType<ParallelCoordinateSystemOption>;
    parallelAxis: PropType<ParallelCoordinateSystemOption>;
    singleAxis: PropType<SingleAxisOption>;
    timeline: PropType<TimelineOption>;
    graphic: PropType<GraphicComponentLooseOption>;
    calendar: PropType<CalendarOption>;
    dataset: PropType<DatasetOption>;
    aria: PropType<AriaOption>;
    series: PropType<SeriesOption>;
    darkMode: {
        type: (StringConstructor | BooleanConstructor)[];
        default: string;
    };
    color: ArrayConstructor;
    backgroundColor: (ObjectConstructor | StringConstructor)[];
    textStyle: ObjectConstructor;
    animation: {
        type: BooleanConstructor;
        default: boolean;
    };
    animationThreshold: NumberConstructor;
    animationDuration: (NumberConstructor | FunctionConstructor)[];
    animationEasing: (StringConstructor | FunctionConstructor)[];
    animationDelay: (NumberConstructor | FunctionConstructor)[];
    animationDurationUpdate: (NumberConstructor | FunctionConstructor)[];
    animationEasingUpdate: (StringConstructor | FunctionConstructor)[];
    animationDelayUpdate: (StringConstructor | FunctionConstructor)[];
    stateAnimation: ObjectConstructor;
    blendMode: StringConstructor;
    hoverLayerThreshold: NumberConstructor;
    useUTC: {
        type: BooleanConstructor;
        default: boolean;
    };
    options: ObjectConstructor;
    media: ArrayConstructor;
    data: (ObjectConstructor | ArrayConstructor)[];
    settings: (ObjectConstructor | ArrayConstructor)[];
    variant: {
        type: StringConstructor;
        default: string;
    };
    loading: {
        type: BooleanConstructor;
        default: boolean;
    };
    emptyText: {
        type: StringConstructor;
        default: string;
    };
    option: {
        type: PropType<EChartsOption>;
        default: () => {};
    };
}, unknown, {
    initOptions: {
        renderer: string;
    };
    needUpdate: boolean;
    setOptionOpts: {};
    mergedOption: {};
}, {
    chartOpts(): Record<string, any>;
    isEmptyData(): boolean;
}, {
    mergePropsToOption(props: any): void;
    forcedUpdate(): void;
}, ComponentOptionsMixin, ComponentOptionsMixin, Record<string, any>, string, VNodeProps & AllowedComponentProps & ComponentCustomProps, Readonly<{
    option: EChartsOption;
    animation: boolean;
    darkMode: string | boolean;
    useUTC: boolean;
    variant: string;
    loading: boolean;
    emptyText: string;
} & {
    title?: TitleOption | undefined;
    legend?: LegendComponentOption | undefined;
    grid?: GridOption | undefined;
    xAxis?: XAXisOption | undefined;
    yAxis?: YAXisOption | undefined;
    polar?: PolarOption | undefined;
    radiusAxis?: RadiusAxisOption | undefined;
    angleAxis?: AngleAxisOption | undefined;
    radar?: RadarOption | undefined;
    dataZoom?: DataZoomComponentOption | undefined;
    visualMap?: VisualMapComponentOption | undefined;
    color?: unknown[] | undefined;
    toolbox?: ToolboxComponentOption | undefined;
    axisPointer?: AxisPointerOption | undefined;
    animationDurationUpdate?: number | Function | undefined;
    animationEasingUpdate?: string | Function | undefined;
    brush?: BrushOption | undefined;
    geo?: GeoOption | undefined;
    parallel?: ParallelCoordinateSystemOption | undefined;
    parallelAxis?: ParallelCoordinateSystemOption | undefined;
    singleAxis?: SingleAxisOption | undefined;
    timeline?: TimelineOption | undefined;
    graphic?: GraphicComponentLooseOption | undefined;
    tooltip?: ToolboxComponentOption | undefined;
    calendar?: CalendarOption | undefined;
    dataset?: DatasetOption | undefined;
    aria?: AriaOption | undefined;
    series?: SeriesOption | undefined;
    blendMode?: string | undefined;
    data?: unknown;
    hoverLayerThreshold?: number | undefined;
    stateAnimation?: Record<string, any> | undefined;
    animationThreshold?: number | undefined;
    animationDuration?: number | Function | undefined;
    animationEasing?: string | Function | undefined;
    animationDelay?: number | Function | undefined;
    animationDelayUpdate?: string | Function | undefined;
    backgroundColor?: unknown;
    textStyle?: Record<string, any> | undefined;
    options?: Record<string, any> | undefined;
    media?: unknown[] | undefined;
    settings?: unknown;
}>, {
    option: EChartsOption;
    animation: boolean;
    darkMode: string | boolean;
    useUTC: boolean;
    variant: string;
    loading: boolean;
    emptyText: string;
}>, EmitsOptions, string, {}> & VNodeProps & AllowedComponentProps & ComponentCustomProps & {
    install(app: App<any>): void;
} & Plugin;

declare const TreeChart: {
    new (...args: any[]): {
        $: ComponentInternalInstance;
        $data: {
            initOptions: {
                renderer: string;
            };
            needUpdate: boolean;
            setOptionOpts: {};
            mergedOption: {};
        };
        $props: Partial<{
            option: EChartsOption;
            animation: boolean;
            darkMode: string | boolean;
            useUTC: boolean;
            variant: string;
            loading: boolean;
            emptyText: string;
        } & {}> & Omit<Readonly<{
            option: EChartsOption;
            animation: boolean;
            darkMode: string | boolean;
            useUTC: boolean;
            variant: string;
            loading: boolean;
            emptyText: string;
        } & {
            title?: TitleOption | undefined;
            legend?: LegendComponentOption | undefined;
            grid?: GridOption | undefined;
            xAxis?: XAXisOption | undefined;
            yAxis?: YAXisOption | undefined;
            polar?: PolarOption | undefined;
            radiusAxis?: RadiusAxisOption | undefined;
            angleAxis?: AngleAxisOption | undefined;
            radar?: RadarOption | undefined;
            dataZoom?: DataZoomComponentOption | undefined;
            visualMap?: VisualMapComponentOption | undefined;
            color?: unknown[] | undefined;
            toolbox?: ToolboxComponentOption | undefined;
            axisPointer?: AxisPointerOption | undefined;
            animationDurationUpdate?: number | Function | undefined;
            animationEasingUpdate?: string | Function | undefined;
            brush?: BrushOption | undefined;
            geo?: GeoOption | undefined;
            parallel?: ParallelCoordinateSystemOption | undefined;
            parallelAxis?: ParallelCoordinateSystemOption | undefined;
            singleAxis?: SingleAxisOption | undefined;
            timeline?: TimelineOption | undefined;
            graphic?: GraphicComponentLooseOption | undefined;
            tooltip?: ToolboxComponentOption | undefined;
            calendar?: CalendarOption | undefined;
            dataset?: DatasetOption | undefined;
            aria?: AriaOption | undefined;
            series?: SeriesOption | undefined;
            blendMode?: string | undefined;
            data?: unknown;
            hoverLayerThreshold?: number | undefined;
            stateAnimation?: Record<string, any> | undefined;
            animationThreshold?: number | undefined;
            animationDuration?: number | Function | undefined;
            animationEasing?: string | Function | undefined;
            animationDelay?: number | Function | undefined;
            animationDelayUpdate?: string | Function | undefined;
            backgroundColor?: unknown;
            textStyle?: Record<string, any> | undefined;
            options?: Record<string, any> | undefined;
            media?: unknown[] | undefined;
            settings?: unknown;
        }> & Readonly<{} & {}> & VNodeProps & AllowedComponentProps & ComponentCustomProps, "option" | "animation" | "darkMode" | "useUTC" | "variant" | "loading" | "emptyText">;
        $attrs: {
            [x: string]: unknown;
        };
        $refs: {
            [x: string]: unknown;
        };
        $slots: Readonly<{
            [name: string]: Slot | undefined;
        }>;
        $root: ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}>> | null;
        $parent: ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}>> | null;
        $emit: ((event: string, ...args: any[]) => void) | ((event: string, ...args: any[]) => void);
        $el: any;
        $options: ComponentOptionsBase<Readonly<{} & {}>, void, {}, {}, {}, ComponentOptionsMixin, DefineComponent<{
            title: PropType<TitleOption>;
            legend: PropType<LegendComponentOption>;
            grid: PropType<GridOption>;
            xAxis: PropType<XAXisOption>;
            yAxis: PropType<YAXisOption>;
            polar: PropType<PolarOption>;
            radiusAxis: PropType<RadiusAxisOption>;
            angleAxis: PropType<AngleAxisOption>;
            radar: PropType<RadarOption>;
            dataZoom: PropType<DataZoomComponentOption>;
            visualMap: PropType<VisualMapComponentOption>;
            tooltip: PropType<ToolboxComponentOption>;
            axisPointer: PropType<AxisPointerOption>;
            toolbox: PropType<ToolboxComponentOption>;
            brush: PropType<BrushOption>;
            geo: PropType<GeoOption>;
            parallel: PropType<ParallelCoordinateSystemOption>;
            parallelAxis: PropType<ParallelCoordinateSystemOption>;
            singleAxis: PropType<SingleAxisOption>;
            timeline: PropType<TimelineOption>;
            graphic: PropType<GraphicComponentLooseOption>;
            calendar: PropType<CalendarOption>;
            dataset: PropType<DatasetOption>;
            aria: PropType<AriaOption>;
            series: PropType<SeriesOption>;
            darkMode: {
                type: (StringConstructor | BooleanConstructor)[];
                default: string;
            };
            color: ArrayConstructor;
            backgroundColor: (ObjectConstructor | StringConstructor)[];
            textStyle: ObjectConstructor;
            animation: {
                type: BooleanConstructor;
                default: boolean;
            };
            animationThreshold: NumberConstructor;
            animationDuration: (NumberConstructor | FunctionConstructor)[];
            animationEasing: (StringConstructor | FunctionConstructor)[];
            animationDelay: (NumberConstructor | FunctionConstructor)[];
            animationDurationUpdate: (NumberConstructor | FunctionConstructor)[];
            animationEasingUpdate: (StringConstructor | FunctionConstructor)[];
            animationDelayUpdate: (StringConstructor | FunctionConstructor)[];
            stateAnimation: ObjectConstructor;
            blendMode: StringConstructor;
            hoverLayerThreshold: NumberConstructor;
            useUTC: {
                type: BooleanConstructor;
                default: boolean;
            };
            options: ObjectConstructor;
            media: ArrayConstructor;
            data: (ObjectConstructor | ArrayConstructor)[];
            settings: (ObjectConstructor | ArrayConstructor)[];
            variant: {
                type: StringConstructor;
                default: string;
            };
            loading: {
                type: BooleanConstructor;
                default: boolean;
            };
            emptyText: {
                type: StringConstructor;
                default: string;
            };
            option: {
                type: PropType<EChartsOption>;
                default: () => {};
            };
        }, unknown, {
            initOptions: {
                renderer: string;
            };
            needUpdate: boolean;
            setOptionOpts: {};
            mergedOption: {};
        }, {
            chartOpts(): Record<string, any>;
            isEmptyData(): boolean;
        }, {
            mergePropsToOption(props: any): void;
            forcedUpdate(): void;
        }, ComponentOptionsMixin, ComponentOptionsMixin, Record<string, any>, string, VNodeProps & AllowedComponentProps & ComponentCustomProps, Readonly<{
            option: EChartsOption;
            animation: boolean;
            darkMode: string | boolean;
            useUTC: boolean;
            variant: string;
            loading: boolean;
            emptyText: string;
        } & {
            title?: TitleOption | undefined;
            legend?: LegendComponentOption | undefined;
            grid?: GridOption | undefined;
            xAxis?: XAXisOption | undefined;
            yAxis?: YAXisOption | undefined;
            polar?: PolarOption | undefined;
            radiusAxis?: RadiusAxisOption | undefined;
            angleAxis?: AngleAxisOption | undefined;
            radar?: RadarOption | undefined;
            dataZoom?: DataZoomComponentOption | undefined;
            visualMap?: VisualMapComponentOption | undefined;
            color?: unknown[] | undefined;
            toolbox?: ToolboxComponentOption | undefined;
            axisPointer?: AxisPointerOption | undefined;
            animationDurationUpdate?: number | Function | undefined;
            animationEasingUpdate?: string | Function | undefined;
            brush?: BrushOption | undefined;
            geo?: GeoOption | undefined;
            parallel?: ParallelCoordinateSystemOption | undefined;
            parallelAxis?: ParallelCoordinateSystemOption | undefined;
            singleAxis?: SingleAxisOption | undefined;
            timeline?: TimelineOption | undefined;
            graphic?: GraphicComponentLooseOption | undefined;
            tooltip?: ToolboxComponentOption | undefined;
            calendar?: CalendarOption | undefined;
            dataset?: DatasetOption | undefined;
            aria?: AriaOption | undefined;
            series?: SeriesOption | undefined;
            blendMode?: string | undefined;
            data?: unknown;
            hoverLayerThreshold?: number | undefined;
            stateAnimation?: Record<string, any> | undefined;
            animationThreshold?: number | undefined;
            animationDuration?: number | Function | undefined;
            animationEasing?: string | Function | undefined;
            animationDelay?: number | Function | undefined;
            animationDelayUpdate?: string | Function | undefined;
            backgroundColor?: unknown;
            textStyle?: Record<string, any> | undefined;
            options?: Record<string, any> | undefined;
            media?: unknown[] | undefined;
            settings?: unknown;
        }>, {
            option: EChartsOption;
            animation: boolean;
            darkMode: string | boolean;
            useUTC: boolean;
            variant: string;
            loading: boolean;
            emptyText: string;
        }>, EmitsOptions, string, {}>;
        $forceUpdate: ReactiveEffect<any>;
        $nextTick: typeof nextTick;
        $watch(source: string | Function, cb: Function, options?: WatchOptions<boolean> | undefined): WatchStopHandle;
    } & Readonly<{
        option: EChartsOption;
        animation: boolean;
        darkMode: string | boolean;
        useUTC: boolean;
        variant: string;
        loading: boolean;
        emptyText: string;
    } & {
        title?: TitleOption | undefined;
        legend?: LegendComponentOption | undefined;
        grid?: GridOption | undefined;
        xAxis?: XAXisOption | undefined;
        yAxis?: YAXisOption | undefined;
        polar?: PolarOption | undefined;
        radiusAxis?: RadiusAxisOption | undefined;
        angleAxis?: AngleAxisOption | undefined;
        radar?: RadarOption | undefined;
        dataZoom?: DataZoomComponentOption | undefined;
        visualMap?: VisualMapComponentOption | undefined;
        color?: unknown[] | undefined;
        toolbox?: ToolboxComponentOption | undefined;
        axisPointer?: AxisPointerOption | undefined;
        animationDurationUpdate?: number | Function | undefined;
        animationEasingUpdate?: string | Function | undefined;
        brush?: BrushOption | undefined;
        geo?: GeoOption | undefined;
        parallel?: ParallelCoordinateSystemOption | undefined;
        parallelAxis?: ParallelCoordinateSystemOption | undefined;
        singleAxis?: SingleAxisOption | undefined;
        timeline?: TimelineOption | undefined;
        graphic?: GraphicComponentLooseOption | undefined;
        tooltip?: ToolboxComponentOption | undefined;
        calendar?: CalendarOption | undefined;
        dataset?: DatasetOption | undefined;
        aria?: AriaOption | undefined;
        series?: SeriesOption | undefined;
        blendMode?: string | undefined;
        data?: unknown;
        hoverLayerThreshold?: number | undefined;
        stateAnimation?: Record<string, any> | undefined;
        animationThreshold?: number | undefined;
        animationDuration?: number | Function | undefined;
        animationEasing?: string | Function | undefined;
        animationDelay?: number | Function | undefined;
        animationDelayUpdate?: string | Function | undefined;
        backgroundColor?: unknown;
        textStyle?: Record<string, any> | undefined;
        options?: Record<string, any> | undefined;
        media?: unknown[] | undefined;
        settings?: unknown;
    }> & Readonly<{} & {}> & ShallowUnwrapRef<{}> & {
        initOptions: {
            renderer: string;
        };
        needUpdate: boolean;
        setOptionOpts: {};
        mergedOption: {};
    } & {
        chartOpts: Record<string, any>;
        isEmptyData: boolean;
    } & {
        mergePropsToOption(props: any): void;
        forcedUpdate(): void;
    } & ComponentCustomProperties;
    __isFragment?: undefined;
    __isTeleport?: undefined;
    __isSuspense?: undefined;
} & ComponentOptionsBase<Readonly<{} & {}>, void, {}, {}, {}, ComponentOptionsMixin, DefineComponent<{
    title: PropType<TitleOption>;
    legend: PropType<LegendComponentOption>;
    grid: PropType<GridOption>;
    xAxis: PropType<XAXisOption>;
    yAxis: PropType<YAXisOption>;
    polar: PropType<PolarOption>;
    radiusAxis: PropType<RadiusAxisOption>;
    angleAxis: PropType<AngleAxisOption>;
    radar: PropType<RadarOption>;
    dataZoom: PropType<DataZoomComponentOption>;
    visualMap: PropType<VisualMapComponentOption>;
    tooltip: PropType<ToolboxComponentOption>;
    axisPointer: PropType<AxisPointerOption>;
    toolbox: PropType<ToolboxComponentOption>;
    brush: PropType<BrushOption>;
    geo: PropType<GeoOption>;
    parallel: PropType<ParallelCoordinateSystemOption>;
    parallelAxis: PropType<ParallelCoordinateSystemOption>;
    singleAxis: PropType<SingleAxisOption>;
    timeline: PropType<TimelineOption>;
    graphic: PropType<GraphicComponentLooseOption>;
    calendar: PropType<CalendarOption>;
    dataset: PropType<DatasetOption>;
    aria: PropType<AriaOption>;
    series: PropType<SeriesOption>;
    darkMode: {
        type: (StringConstructor | BooleanConstructor)[];
        default: string;
    };
    color: ArrayConstructor;
    backgroundColor: (ObjectConstructor | StringConstructor)[];
    textStyle: ObjectConstructor;
    animation: {
        type: BooleanConstructor;
        default: boolean;
    };
    animationThreshold: NumberConstructor;
    animationDuration: (NumberConstructor | FunctionConstructor)[];
    animationEasing: (StringConstructor | FunctionConstructor)[];
    animationDelay: (NumberConstructor | FunctionConstructor)[];
    animationDurationUpdate: (NumberConstructor | FunctionConstructor)[];
    animationEasingUpdate: (StringConstructor | FunctionConstructor)[];
    animationDelayUpdate: (StringConstructor | FunctionConstructor)[];
    stateAnimation: ObjectConstructor;
    blendMode: StringConstructor;
    hoverLayerThreshold: NumberConstructor;
    useUTC: {
        type: BooleanConstructor;
        default: boolean;
    };
    options: ObjectConstructor;
    media: ArrayConstructor;
    data: (ObjectConstructor | ArrayConstructor)[];
    settings: (ObjectConstructor | ArrayConstructor)[];
    variant: {
        type: StringConstructor;
        default: string;
    };
    loading: {
        type: BooleanConstructor;
        default: boolean;
    };
    emptyText: {
        type: StringConstructor;
        default: string;
    };
    option: {
        type: PropType<EChartsOption>;
        default: () => {};
    };
}, unknown, {
    initOptions: {
        renderer: string;
    };
    needUpdate: boolean;
    setOptionOpts: {};
    mergedOption: {};
}, {
    chartOpts(): Record<string, any>;
    isEmptyData(): boolean;
}, {
    mergePropsToOption(props: any): void;
    forcedUpdate(): void;
}, ComponentOptionsMixin, ComponentOptionsMixin, Record<string, any>, string, VNodeProps & AllowedComponentProps & ComponentCustomProps, Readonly<{
    option: EChartsOption;
    animation: boolean;
    darkMode: string | boolean;
    useUTC: boolean;
    variant: string;
    loading: boolean;
    emptyText: string;
} & {
    title?: TitleOption | undefined;
    legend?: LegendComponentOption | undefined;
    grid?: GridOption | undefined;
    xAxis?: XAXisOption | undefined;
    yAxis?: YAXisOption | undefined;
    polar?: PolarOption | undefined;
    radiusAxis?: RadiusAxisOption | undefined;
    angleAxis?: AngleAxisOption | undefined;
    radar?: RadarOption | undefined;
    dataZoom?: DataZoomComponentOption | undefined;
    visualMap?: VisualMapComponentOption | undefined;
    color?: unknown[] | undefined;
    toolbox?: ToolboxComponentOption | undefined;
    axisPointer?: AxisPointerOption | undefined;
    animationDurationUpdate?: number | Function | undefined;
    animationEasingUpdate?: string | Function | undefined;
    brush?: BrushOption | undefined;
    geo?: GeoOption | undefined;
    parallel?: ParallelCoordinateSystemOption | undefined;
    parallelAxis?: ParallelCoordinateSystemOption | undefined;
    singleAxis?: SingleAxisOption | undefined;
    timeline?: TimelineOption | undefined;
    graphic?: GraphicComponentLooseOption | undefined;
    tooltip?: ToolboxComponentOption | undefined;
    calendar?: CalendarOption | undefined;
    dataset?: DatasetOption | undefined;
    aria?: AriaOption | undefined;
    series?: SeriesOption | undefined;
    blendMode?: string | undefined;
    data?: unknown;
    hoverLayerThreshold?: number | undefined;
    stateAnimation?: Record<string, any> | undefined;
    animationThreshold?: number | undefined;
    animationDuration?: number | Function | undefined;
    animationEasing?: string | Function | undefined;
    animationDelay?: number | Function | undefined;
    animationDelayUpdate?: string | Function | undefined;
    backgroundColor?: unknown;
    textStyle?: Record<string, any> | undefined;
    options?: Record<string, any> | undefined;
    media?: unknown[] | undefined;
    settings?: unknown;
}>, {
    option: EChartsOption;
    animation: boolean;
    darkMode: string | boolean;
    useUTC: boolean;
    variant: string;
    loading: boolean;
    emptyText: string;
}>, EmitsOptions, string, {}> & VNodeProps & AllowedComponentProps & ComponentCustomProps & {
    install(app: App<any>): void;
} & Plugin;

declare const TreemapChart: {
    new (...args: any[]): {
        $: ComponentInternalInstance;
        $data: {
            initOptions: {
                renderer: string;
            };
            needUpdate: boolean;
            setOptionOpts: {};
            mergedOption: {};
        };
        $props: Partial<{
            option: EChartsOption;
            animation: boolean;
            darkMode: string | boolean;
            useUTC: boolean;
            variant: string;
            loading: boolean;
            emptyText: string;
        } & {}> & Omit<Readonly<{
            option: EChartsOption;
            animation: boolean;
            darkMode: string | boolean;
            useUTC: boolean;
            variant: string;
            loading: boolean;
            emptyText: string;
        } & {
            title?: TitleOption | undefined;
            legend?: LegendComponentOption | undefined;
            grid?: GridOption | undefined;
            xAxis?: XAXisOption | undefined;
            yAxis?: YAXisOption | undefined;
            polar?: PolarOption | undefined;
            radiusAxis?: RadiusAxisOption | undefined;
            angleAxis?: AngleAxisOption | undefined;
            radar?: RadarOption | undefined;
            dataZoom?: DataZoomComponentOption | undefined;
            visualMap?: VisualMapComponentOption | undefined;
            color?: unknown[] | undefined;
            toolbox?: ToolboxComponentOption | undefined;
            axisPointer?: AxisPointerOption | undefined;
            animationDurationUpdate?: number | Function | undefined;
            animationEasingUpdate?: string | Function | undefined;
            brush?: BrushOption | undefined;
            geo?: GeoOption | undefined;
            parallel?: ParallelCoordinateSystemOption | undefined;
            parallelAxis?: ParallelCoordinateSystemOption | undefined;
            singleAxis?: SingleAxisOption | undefined;
            timeline?: TimelineOption | undefined;
            graphic?: GraphicComponentLooseOption | undefined;
            tooltip?: ToolboxComponentOption | undefined;
            calendar?: CalendarOption | undefined;
            dataset?: DatasetOption | undefined;
            aria?: AriaOption | undefined;
            series?: SeriesOption | undefined;
            blendMode?: string | undefined;
            data?: unknown;
            hoverLayerThreshold?: number | undefined;
            stateAnimation?: Record<string, any> | undefined;
            animationThreshold?: number | undefined;
            animationDuration?: number | Function | undefined;
            animationEasing?: string | Function | undefined;
            animationDelay?: number | Function | undefined;
            animationDelayUpdate?: string | Function | undefined;
            backgroundColor?: unknown;
            textStyle?: Record<string, any> | undefined;
            options?: Record<string, any> | undefined;
            media?: unknown[] | undefined;
            settings?: unknown;
        }> & Readonly<{} & {}> & VNodeProps & AllowedComponentProps & ComponentCustomProps, "option" | "animation" | "darkMode" | "useUTC" | "variant" | "loading" | "emptyText">;
        $attrs: {
            [x: string]: unknown;
        };
        $refs: {
            [x: string]: unknown;
        };
        $slots: Readonly<{
            [name: string]: Slot | undefined;
        }>;
        $root: ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}>> | null;
        $parent: ComponentPublicInstance<{}, {}, {}, {}, {}, {}, {}, {}, false, ComponentOptionsBase<any, any, any, any, any, any, any, any, any, {}>> | null;
        $emit: ((event: string, ...args: any[]) => void) | ((event: string, ...args: any[]) => void);
        $el: any;
        $options: ComponentOptionsBase<Readonly<{} & {}>, void, {}, {}, {}, ComponentOptionsMixin, DefineComponent<{
            title: PropType<TitleOption>;
            legend: PropType<LegendComponentOption>;
            grid: PropType<GridOption>;
            xAxis: PropType<XAXisOption>;
            yAxis: PropType<YAXisOption>;
            polar: PropType<PolarOption>;
            radiusAxis: PropType<RadiusAxisOption>;
            angleAxis: PropType<AngleAxisOption>;
            radar: PropType<RadarOption>;
            dataZoom: PropType<DataZoomComponentOption>;
            visualMap: PropType<VisualMapComponentOption>;
            tooltip: PropType<ToolboxComponentOption>;
            axisPointer: PropType<AxisPointerOption>;
            toolbox: PropType<ToolboxComponentOption>;
            brush: PropType<BrushOption>;
            geo: PropType<GeoOption>;
            parallel: PropType<ParallelCoordinateSystemOption>;
            parallelAxis: PropType<ParallelCoordinateSystemOption>;
            singleAxis: PropType<SingleAxisOption>;
            timeline: PropType<TimelineOption>;
            graphic: PropType<GraphicComponentLooseOption>;
            calendar: PropType<CalendarOption>;
            dataset: PropType<DatasetOption>;
            aria: PropType<AriaOption>;
            series: PropType<SeriesOption>;
            darkMode: {
                type: (StringConstructor | BooleanConstructor)[];
                default: string;
            };
            color: ArrayConstructor;
            backgroundColor: (ObjectConstructor | StringConstructor)[];
            textStyle: ObjectConstructor;
            animation: {
                type: BooleanConstructor;
                default: boolean;
            };
            animationThreshold: NumberConstructor;
            animationDuration: (NumberConstructor | FunctionConstructor)[];
            animationEasing: (StringConstructor | FunctionConstructor)[];
            animationDelay: (NumberConstructor | FunctionConstructor)[];
            animationDurationUpdate: (NumberConstructor | FunctionConstructor)[];
            animationEasingUpdate: (StringConstructor | FunctionConstructor)[];
            animationDelayUpdate: (StringConstructor | FunctionConstructor)[];
            stateAnimation: ObjectConstructor;
            blendMode: StringConstructor;
            hoverLayerThreshold: NumberConstructor;
            useUTC: {
                type: BooleanConstructor;
                default: boolean;
            };
            options: ObjectConstructor;
            media: ArrayConstructor;
            data: (ObjectConstructor | ArrayConstructor)[];
            settings: (ObjectConstructor | ArrayConstructor)[];
            variant: {
                type: StringConstructor;
                default: string;
            };
            loading: {
                type: BooleanConstructor;
                default: boolean;
            };
            emptyText: {
                type: StringConstructor;
                default: string;
            };
            option: {
                type: PropType<EChartsOption>;
                default: () => {};
            };
        }, unknown, {
            initOptions: {
                renderer: string;
            };
            needUpdate: boolean;
            setOptionOpts: {};
            mergedOption: {};
        }, {
            chartOpts(): Record<string, any>;
            isEmptyData(): boolean;
        }, {
            mergePropsToOption(props: any): void;
            forcedUpdate(): void;
        }, ComponentOptionsMixin, ComponentOptionsMixin, Record<string, any>, string, VNodeProps & AllowedComponentProps & ComponentCustomProps, Readonly<{
            option: EChartsOption;
            animation: boolean;
            darkMode: string | boolean;
            useUTC: boolean;
            variant: string;
            loading: boolean;
            emptyText: string;
        } & {
            title?: TitleOption | undefined;
            legend?: LegendComponentOption | undefined;
            grid?: GridOption | undefined;
            xAxis?: XAXisOption | undefined;
            yAxis?: YAXisOption | undefined;
            polar?: PolarOption | undefined;
            radiusAxis?: RadiusAxisOption | undefined;
            angleAxis?: AngleAxisOption | undefined;
            radar?: RadarOption | undefined;
            dataZoom?: DataZoomComponentOption | undefined;
            visualMap?: VisualMapComponentOption | undefined;
            color?: unknown[] | undefined;
            toolbox?: ToolboxComponentOption | undefined;
            axisPointer?: AxisPointerOption | undefined;
            animationDurationUpdate?: number | Function | undefined;
            animationEasingUpdate?: string | Function | undefined;
            brush?: BrushOption | undefined;
            geo?: GeoOption | undefined;
            parallel?: ParallelCoordinateSystemOption | undefined;
            parallelAxis?: ParallelCoordinateSystemOption | undefined;
            singleAxis?: SingleAxisOption | undefined;
            timeline?: TimelineOption | undefined;
            graphic?: GraphicComponentLooseOption | undefined;
            tooltip?: ToolboxComponentOption | undefined;
            calendar?: CalendarOption | undefined;
            dataset?: DatasetOption | undefined;
            aria?: AriaOption | undefined;
            series?: SeriesOption | undefined;
            blendMode?: string | undefined;
            data?: unknown;
            hoverLayerThreshold?: number | undefined;
            stateAnimation?: Record<string, any> | undefined;
            animationThreshold?: number | undefined;
            animationDuration?: number | Function | undefined;
            animationEasing?: string | Function | undefined;
            animationDelay?: number | Function | undefined;
            animationDelayUpdate?: string | Function | undefined;
            backgroundColor?: unknown;
            textStyle?: Record<string, any> | undefined;
            options?: Record<string, any> | undefined;
            media?: unknown[] | undefined;
            settings?: unknown;
        }>, {
            option: EChartsOption;
            animation: boolean;
            darkMode: string | boolean;
            useUTC: boolean;
            variant: string;
            loading: boolean;
            emptyText: string;
        }>, EmitsOptions, string, {}>;
        $forceUpdate: ReactiveEffect<any>;
        $nextTick: typeof nextTick;
        $watch(source: string | Function, cb: Function, options?: WatchOptions<boolean> | undefined): WatchStopHandle;
    } & Readonly<{
        option: EChartsOption;
        animation: boolean;
        darkMode: string | boolean;
        useUTC: boolean;
        variant: string;
        loading: boolean;
        emptyText: string;
    } & {
        title?: TitleOption | undefined;
        legend?: LegendComponentOption | undefined;
        grid?: GridOption | undefined;
        xAxis?: XAXisOption | undefined;
        yAxis?: YAXisOption | undefined;
        polar?: PolarOption | undefined;
        radiusAxis?: RadiusAxisOption | undefined;
        angleAxis?: AngleAxisOption | undefined;
        radar?: RadarOption | undefined;
        dataZoom?: DataZoomComponentOption | undefined;
        visualMap?: VisualMapComponentOption | undefined;
        color?: unknown[] | undefined;
        toolbox?: ToolboxComponentOption | undefined;
        axisPointer?: AxisPointerOption | undefined;
        animationDurationUpdate?: number | Function | undefined;
        animationEasingUpdate?: string | Function | undefined;
        brush?: BrushOption | undefined;
        geo?: GeoOption | undefined;
        parallel?: ParallelCoordinateSystemOption | undefined;
        parallelAxis?: ParallelCoordinateSystemOption | undefined;
        singleAxis?: SingleAxisOption | undefined;
        timeline?: TimelineOption | undefined;
        graphic?: GraphicComponentLooseOption | undefined;
        tooltip?: ToolboxComponentOption | undefined;
        calendar?: CalendarOption | undefined;
        dataset?: DatasetOption | undefined;
        aria?: AriaOption | undefined;
        series?: SeriesOption | undefined;
        blendMode?: string | undefined;
        data?: unknown;
        hoverLayerThreshold?: number | undefined;
        stateAnimation?: Record<string, any> | undefined;
        animationThreshold?: number | undefined;
        animationDuration?: number | Function | undefined;
        animationEasing?: string | Function | undefined;
        animationDelay?: number | Function | undefined;
        animationDelayUpdate?: string | Function | undefined;
        backgroundColor?: unknown;
        textStyle?: Record<string, any> | undefined;
        options?: Record<string, any> | undefined;
        media?: unknown[] | undefined;
        settings?: unknown;
    }> & Readonly<{} & {}> & ShallowUnwrapRef<{}> & {
        initOptions: {
            renderer: string;
        };
        needUpdate: boolean;
        setOptionOpts: {};
        mergedOption: {};
    } & {
        chartOpts: Record<string, any>;
        isEmptyData: boolean;
    } & {
        mergePropsToOption(props: any): void;
        forcedUpdate(): void;
    } & ComponentCustomProperties;
    __isFragment?: undefined;
    __isTeleport?: undefined;
    __isSuspense?: undefined;
} & ComponentOptionsBase<Readonly<{} & {}>, void, {}, {}, {}, ComponentOptionsMixin, DefineComponent<{
    title: PropType<TitleOption>;
    legend: PropType<LegendComponentOption>;
    grid: PropType<GridOption>;
    xAxis: PropType<XAXisOption>;
    yAxis: PropType<YAXisOption>;
    polar: PropType<PolarOption>;
    radiusAxis: PropType<RadiusAxisOption>;
    angleAxis: PropType<AngleAxisOption>;
    radar: PropType<RadarOption>;
    dataZoom: PropType<DataZoomComponentOption>;
    visualMap: PropType<VisualMapComponentOption>;
    tooltip: PropType<ToolboxComponentOption>;
    axisPointer: PropType<AxisPointerOption>;
    toolbox: PropType<ToolboxComponentOption>;
    brush: PropType<BrushOption>;
    geo: PropType<GeoOption>;
    parallel: PropType<ParallelCoordinateSystemOption>;
    parallelAxis: PropType<ParallelCoordinateSystemOption>;
    singleAxis: PropType<SingleAxisOption>;
    timeline: PropType<TimelineOption>;
    graphic: PropType<GraphicComponentLooseOption>;
    calendar: PropType<CalendarOption>;
    dataset: PropType<DatasetOption>;
    aria: PropType<AriaOption>;
    series: PropType<SeriesOption>;
    darkMode: {
        type: (StringConstructor | BooleanConstructor)[];
        default: string;
    };
    color: ArrayConstructor;
    backgroundColor: (ObjectConstructor | StringConstructor)[];
    textStyle: ObjectConstructor;
    animation: {
        type: BooleanConstructor;
        default: boolean;
    };
    animationThreshold: NumberConstructor;
    animationDuration: (NumberConstructor | FunctionConstructor)[];
    animationEasing: (StringConstructor | FunctionConstructor)[];
    animationDelay: (NumberConstructor | FunctionConstructor)[];
    animationDurationUpdate: (NumberConstructor | FunctionConstructor)[];
    animationEasingUpdate: (StringConstructor | FunctionConstructor)[];
    animationDelayUpdate: (StringConstructor | FunctionConstructor)[];
    stateAnimation: ObjectConstructor;
    blendMode: StringConstructor;
    hoverLayerThreshold: NumberConstructor;
    useUTC: {
        type: BooleanConstructor;
        default: boolean;
    };
    options: ObjectConstructor;
    media: ArrayConstructor;
    data: (ObjectConstructor | ArrayConstructor)[];
    settings: (ObjectConstructor | ArrayConstructor)[];
    variant: {
        type: StringConstructor;
        default: string;
    };
    loading: {
        type: BooleanConstructor;
        default: boolean;
    };
    emptyText: {
        type: StringConstructor;
        default: string;
    };
    option: {
        type: PropType<EChartsOption>;
        default: () => {};
    };
}, unknown, {
    initOptions: {
        renderer: string;
    };
    needUpdate: boolean;
    setOptionOpts: {};
    mergedOption: {};
}, {
    chartOpts(): Record<string, any>;
    isEmptyData(): boolean;
}, {
    mergePropsToOption(props: any): void;
    forcedUpdate(): void;
}, ComponentOptionsMixin, ComponentOptionsMixin, Record<string, any>, string, VNodeProps & AllowedComponentProps & ComponentCustomProps, Readonly<{
    option: EChartsOption;
    animation: boolean;
    darkMode: string | boolean;
    useUTC: boolean;
    variant: string;
    loading: boolean;
    emptyText: string;
} & {
    title?: TitleOption | undefined;
    legend?: LegendComponentOption | undefined;
    grid?: GridOption | undefined;
    xAxis?: XAXisOption | undefined;
    yAxis?: YAXisOption | undefined;
    polar?: PolarOption | undefined;
    radiusAxis?: RadiusAxisOption | undefined;
    angleAxis?: AngleAxisOption | undefined;
    radar?: RadarOption | undefined;
    dataZoom?: DataZoomComponentOption | undefined;
    visualMap?: VisualMapComponentOption | undefined;
    color?: unknown[] | undefined;
    toolbox?: ToolboxComponentOption | undefined;
    axisPointer?: AxisPointerOption | undefined;
    animationDurationUpdate?: number | Function | undefined;
    animationEasingUpdate?: string | Function | undefined;
    brush?: BrushOption | undefined;
    geo?: GeoOption | undefined;
    parallel?: ParallelCoordinateSystemOption | undefined;
    parallelAxis?: ParallelCoordinateSystemOption | undefined;
    singleAxis?: SingleAxisOption | undefined;
    timeline?: TimelineOption | undefined;
    graphic?: GraphicComponentLooseOption | undefined;
    tooltip?: ToolboxComponentOption | undefined;
    calendar?: CalendarOption | undefined;
    dataset?: DatasetOption | undefined;
    aria?: AriaOption | undefined;
    series?: SeriesOption | undefined;
    blendMode?: string | undefined;
    data?: unknown;
    hoverLayerThreshold?: number | undefined;
    stateAnimation?: Record<string, any> | undefined;
    animationThreshold?: number | undefined;
    animationDuration?: number | Function | undefined;
    animationEasing?: string | Function | undefined;
    animationDelay?: number | Function | undefined;
    animationDelayUpdate?: string | Function | undefined;
    backgroundColor?: unknown;
    textStyle?: Record<string, any> | undefined;
    options?: Record<string, any> | undefined;
    media?: unknown[] | undefined;
    settings?: unknown;
}>, {
    option: EChartsOption;
    animation: boolean;
    darkMode: string | boolean;
    useUTC: boolean;
    variant: string;
    loading: boolean;
    emptyText: string;
}>, EmitsOptions, string, {}> & VNodeProps & AllowedComponentProps & ComponentCustomProps & {
    install(app: App<any>): void;
} & Plugin;

declare const install: (app: App) => void;

export default install;
export { BarChart, FunnelChart, GaugeChart, LineChart, PieChart, RadarChart, ScatterChart, TreeChart, TreemapChart, VeBarChart, VeChart };
